from .async_client import AdGroupServiceAsyncClient as AdGroupServiceAsyncClient
from .client import AdGroupServiceClient as AdGroupServiceClient

__all__ = ["AdGroupServiceClient", "AdGroupServiceAsyncClient"]



from typing import AsyncIterable, Awaitable, Callable, MutableSequence, Sequence

from _typeshed import Incomplete
from google.api_core import gapic_v1, retry_async as retries
from google.api_core.client_options import ClientOptions
from google.auth import credentials as ga_credentials

from google.ads.googleads.v23.services.services.google_ads_service import pagers
from google.ads.googleads.v23.services.types import google_ads_service

from .transports.base import GoogleAdsServiceTransport

__all__ = ["GoogleAdsServiceAsyncClient"]

class GoogleAdsServiceAsyncClient:
    DEFAULT_ENDPOINT: Incomplete
    DEFAULT_MTLS_ENDPOINT: Incomplete
    accessible_bidding_strategy_path: Incomplete
    parse_accessible_bidding_strategy_path: Incomplete
    account_budget_path: Incomplete
    parse_account_budget_path: Incomplete
    account_budget_proposal_path: Incomplete
    parse_account_budget_proposal_path: Incomplete
    account_link_path: Incomplete
    parse_account_link_path: Incomplete
    ad_path: Incomplete
    parse_ad_path: Incomplete
    ad_group_path: Incomplete
    parse_ad_group_path: Incomplete
    ad_group_ad_path: Incomplete
    parse_ad_group_ad_path: Incomplete
    ad_group_ad_asset_combination_view_path: Incomplete
    parse_ad_group_ad_asset_combination_view_path: Incomplete
    ad_group_ad_asset_view_path: Incomplete
    parse_ad_group_ad_asset_view_path: Incomplete
    ad_group_ad_label_path: Incomplete
    parse_ad_group_ad_label_path: Incomplete
    ad_group_asset_path: Incomplete
    parse_ad_group_asset_path: Incomplete
    ad_group_asset_set_path: Incomplete
    parse_ad_group_asset_set_path: Incomplete
    ad_group_audience_view_path: Incomplete
    parse_ad_group_audience_view_path: Incomplete
    ad_group_bid_modifier_path: Incomplete
    parse_ad_group_bid_modifier_path: Incomplete
    ad_group_criterion_path: Incomplete
    parse_ad_group_criterion_path: Incomplete
    ad_group_criterion_customizer_path: Incomplete
    parse_ad_group_criterion_customizer_path: Incomplete
    ad_group_criterion_label_path: Incomplete
    parse_ad_group_criterion_label_path: Incomplete
    ad_group_criterion_simulation_path: Incomplete
    parse_ad_group_criterion_simulation_path: Incomplete
    ad_group_customizer_path: Incomplete
    parse_ad_group_customizer_path: Incomplete
    ad_group_label_path: Incomplete
    parse_ad_group_label_path: Incomplete
    ad_group_simulation_path: Incomplete
    parse_ad_group_simulation_path: Incomplete
    ad_parameter_path: Incomplete
    parse_ad_parameter_path: Incomplete
    ad_schedule_view_path: Incomplete
    parse_ad_schedule_view_path: Incomplete
    age_range_view_path: Incomplete
    parse_age_range_view_path: Incomplete
    ai_max_search_term_ad_combination_view_path: Incomplete
    parse_ai_max_search_term_ad_combination_view_path: Incomplete
    android_privacy_shared_key_google_ad_group_path: Incomplete
    parse_android_privacy_shared_key_google_ad_group_path: Incomplete
    android_privacy_shared_key_google_campaign_path: Incomplete
    parse_android_privacy_shared_key_google_campaign_path: Incomplete
    android_privacy_shared_key_google_network_type_path: Incomplete
    parse_android_privacy_shared_key_google_network_type_path: Incomplete
    applied_incentive_path: Incomplete
    parse_applied_incentive_path: Incomplete
    asset_path: Incomplete
    parse_asset_path: Incomplete
    asset_field_type_view_path: Incomplete
    parse_asset_field_type_view_path: Incomplete
    asset_group_path: Incomplete
    parse_asset_group_path: Incomplete
    asset_group_asset_path: Incomplete
    parse_asset_group_asset_path: Incomplete
    asset_group_listing_group_filter_path: Incomplete
    parse_asset_group_listing_group_filter_path: Incomplete
    asset_group_product_group_view_path: Incomplete
    parse_asset_group_product_group_view_path: Incomplete
    asset_group_signal_path: Incomplete
    parse_asset_group_signal_path: Incomplete
    asset_group_top_combination_view_path: Incomplete
    parse_asset_group_top_combination_view_path: Incomplete
    asset_set_path: Incomplete
    parse_asset_set_path: Incomplete
    asset_set_asset_path: Incomplete
    parse_asset_set_asset_path: Incomplete
    asset_set_type_view_path: Incomplete
    parse_asset_set_type_view_path: Incomplete
    audience_path: Incomplete
    parse_audience_path: Incomplete
    batch_job_path: Incomplete
    parse_batch_job_path: Incomplete
    bidding_data_exclusion_path: Incomplete
    parse_bidding_data_exclusion_path: Incomplete
    bidding_seasonality_adjustment_path: Incomplete
    parse_bidding_seasonality_adjustment_path: Incomplete
    bidding_strategy_path: Incomplete
    parse_bidding_strategy_path: Incomplete
    bidding_strategy_simulation_path: Incomplete
    parse_bidding_strategy_simulation_path: Incomplete
    billing_setup_path: Incomplete
    parse_billing_setup_path: Incomplete
    call_view_path: Incomplete
    parse_call_view_path: Incomplete
    campaign_path: Incomplete
    parse_campaign_path: Incomplete
    campaign_aggregate_asset_view_path: Incomplete
    parse_campaign_aggregate_asset_view_path: Incomplete
    campaign_asset_path: Incomplete
    parse_campaign_asset_path: Incomplete
    campaign_asset_set_path: Incomplete
    parse_campaign_asset_set_path: Incomplete
    campaign_audience_view_path: Incomplete
    parse_campaign_audience_view_path: Incomplete
    campaign_bid_modifier_path: Incomplete
    parse_campaign_bid_modifier_path: Incomplete
    campaign_budget_path: Incomplete
    parse_campaign_budget_path: Incomplete
    campaign_conversion_goal_path: Incomplete
    parse_campaign_conversion_goal_path: Incomplete
    campaign_criterion_path: Incomplete
    parse_campaign_criterion_path: Incomplete
    campaign_customizer_path: Incomplete
    parse_campaign_customizer_path: Incomplete
    campaign_draft_path: Incomplete
    parse_campaign_draft_path: Incomplete
    campaign_goal_config_path: Incomplete
    parse_campaign_goal_config_path: Incomplete
    campaign_group_path: Incomplete
    parse_campaign_group_path: Incomplete
    campaign_label_path: Incomplete
    parse_campaign_label_path: Incomplete
    campaign_lifecycle_goal_path: Incomplete
    parse_campaign_lifecycle_goal_path: Incomplete
    campaign_search_term_insight_path: Incomplete
    parse_campaign_search_term_insight_path: Incomplete
    campaign_search_term_view_path: Incomplete
    parse_campaign_search_term_view_path: Incomplete
    campaign_shared_set_path: Incomplete
    parse_campaign_shared_set_path: Incomplete
    campaign_simulation_path: Incomplete
    parse_campaign_simulation_path: Incomplete
    carrier_constant_path: Incomplete
    parse_carrier_constant_path: Incomplete
    change_event_path: Incomplete
    parse_change_event_path: Incomplete
    change_status_path: Incomplete
    parse_change_status_path: Incomplete
    channel_aggregate_asset_view_path: Incomplete
    parse_channel_aggregate_asset_view_path: Incomplete
    click_view_path: Incomplete
    parse_click_view_path: Incomplete
    combined_audience_path: Incomplete
    parse_combined_audience_path: Incomplete
    content_criterion_view_path: Incomplete
    parse_content_criterion_view_path: Incomplete
    conversion_action_path: Incomplete
    parse_conversion_action_path: Incomplete
    conversion_custom_variable_path: Incomplete
    parse_conversion_custom_variable_path: Incomplete
    conversion_goal_campaign_config_path: Incomplete
    parse_conversion_goal_campaign_config_path: Incomplete
    conversion_value_rule_path: Incomplete
    parse_conversion_value_rule_path: Incomplete
    conversion_value_rule_set_path: Incomplete
    parse_conversion_value_rule_set_path: Incomplete
    currency_constant_path: Incomplete
    parse_currency_constant_path: Incomplete
    custom_audience_path: Incomplete
    parse_custom_audience_path: Incomplete
    custom_conversion_goal_path: Incomplete
    parse_custom_conversion_goal_path: Incomplete
    customer_path: Incomplete
    parse_customer_path: Incomplete
    customer_asset_path: Incomplete
    parse_customer_asset_path: Incomplete
    customer_asset_set_path: Incomplete
    parse_customer_asset_set_path: Incomplete
    customer_client_path: Incomplete
    parse_customer_client_path: Incomplete
    customer_client_link_path: Incomplete
    parse_customer_client_link_path: Incomplete
    customer_conversion_goal_path: Incomplete
    parse_customer_conversion_goal_path: Incomplete
    customer_customizer_path: Incomplete
    parse_customer_customizer_path: Incomplete
    customer_label_path: Incomplete
    parse_customer_label_path: Incomplete
    customer_lifecycle_goal_path: Incomplete
    parse_customer_lifecycle_goal_path: Incomplete
    customer_manager_link_path: Incomplete
    parse_customer_manager_link_path: Incomplete
    customer_negative_criterion_path: Incomplete
    parse_customer_negative_criterion_path: Incomplete
    customer_search_term_insight_path: Incomplete
    parse_customer_search_term_insight_path: Incomplete
    customer_user_access_path: Incomplete
    parse_customer_user_access_path: Incomplete
    customer_user_access_invitation_path: Incomplete
    parse_customer_user_access_invitation_path: Incomplete
    custom_interest_path: Incomplete
    parse_custom_interest_path: Incomplete
    customizer_attribute_path: Incomplete
    parse_customizer_attribute_path: Incomplete
    data_link_path: Incomplete
    parse_data_link_path: Incomplete
    detail_content_suitability_placement_view_path: Incomplete
    parse_detail_content_suitability_placement_view_path: Incomplete
    detailed_demographic_path: Incomplete
    parse_detailed_demographic_path: Incomplete
    detail_placement_view_path: Incomplete
    parse_detail_placement_view_path: Incomplete
    display_keyword_view_path: Incomplete
    parse_display_keyword_view_path: Incomplete
    distance_view_path: Incomplete
    parse_distance_view_path: Incomplete
    domain_category_path: Incomplete
    parse_domain_category_path: Incomplete
    dynamic_search_ads_search_term_view_path: Incomplete
    parse_dynamic_search_ads_search_term_view_path: Incomplete
    expanded_landing_page_view_path: Incomplete
    parse_expanded_landing_page_view_path: Incomplete
    experiment_path: Incomplete
    parse_experiment_path: Incomplete
    experiment_arm_path: Incomplete
    parse_experiment_arm_path: Incomplete
    final_url_expansion_asset_view_path: Incomplete
    parse_final_url_expansion_asset_view_path: Incomplete
    gender_view_path: Incomplete
    parse_gender_view_path: Incomplete
    geographic_view_path: Incomplete
    parse_geographic_view_path: Incomplete
    geo_target_constant_path: Incomplete
    parse_geo_target_constant_path: Incomplete
    goal_path: Incomplete
    parse_goal_path: Incomplete
    group_content_suitability_placement_view_path: Incomplete
    parse_group_content_suitability_placement_view_path: Incomplete
    group_placement_view_path: Incomplete
    parse_group_placement_view_path: Incomplete
    hotel_group_view_path: Incomplete
    parse_hotel_group_view_path: Incomplete
    hotel_performance_view_path: Incomplete
    parse_hotel_performance_view_path: Incomplete
    hotel_reconciliation_path: Incomplete
    parse_hotel_reconciliation_path: Incomplete
    income_range_view_path: Incomplete
    parse_income_range_view_path: Incomplete
    keyword_plan_path: Incomplete
    parse_keyword_plan_path: Incomplete
    keyword_plan_ad_group_path: Incomplete
    parse_keyword_plan_ad_group_path: Incomplete
    keyword_plan_ad_group_keyword_path: Incomplete
    parse_keyword_plan_ad_group_keyword_path: Incomplete
    keyword_plan_campaign_path: Incomplete
    parse_keyword_plan_campaign_path: Incomplete
    keyword_plan_campaign_keyword_path: Incomplete
    parse_keyword_plan_campaign_keyword_path: Incomplete
    keyword_theme_constant_path: Incomplete
    parse_keyword_theme_constant_path: Incomplete
    keyword_view_path: Incomplete
    parse_keyword_view_path: Incomplete
    label_path: Incomplete
    parse_label_path: Incomplete
    landing_page_view_path: Incomplete
    parse_landing_page_view_path: Incomplete
    language_constant_path: Incomplete
    parse_language_constant_path: Incomplete
    lead_form_submission_data_path: Incomplete
    parse_lead_form_submission_data_path: Incomplete
    life_event_path: Incomplete
    parse_life_event_path: Incomplete
    local_services_employee_path: Incomplete
    parse_local_services_employee_path: Incomplete
    local_services_lead_path: Incomplete
    parse_local_services_lead_path: Incomplete
    local_services_lead_conversation_path: Incomplete
    parse_local_services_lead_conversation_path: Incomplete
    local_services_verification_artifact_path: Incomplete
    parse_local_services_verification_artifact_path: Incomplete
    location_interest_view_path: Incomplete
    parse_location_interest_view_path: Incomplete
    location_view_path: Incomplete
    parse_location_view_path: Incomplete
    managed_placement_view_path: Incomplete
    parse_managed_placement_view_path: Incomplete
    matched_location_interest_view_path: Incomplete
    parse_matched_location_interest_view_path: Incomplete
    media_file_path: Incomplete
    parse_media_file_path: Incomplete
    mobile_app_category_constant_path: Incomplete
    parse_mobile_app_category_constant_path: Incomplete
    mobile_device_constant_path: Incomplete
    parse_mobile_device_constant_path: Incomplete
    offline_conversion_upload_client_summary_path: Incomplete
    parse_offline_conversion_upload_client_summary_path: Incomplete
    offline_conversion_upload_conversion_action_summary_path: Incomplete
    parse_offline_conversion_upload_conversion_action_summary_path: Incomplete
    offline_user_data_job_path: Incomplete
    parse_offline_user_data_job_path: Incomplete
    operating_system_version_constant_path: Incomplete
    parse_operating_system_version_constant_path: Incomplete
    paid_organic_search_term_view_path: Incomplete
    parse_paid_organic_search_term_view_path: Incomplete
    parental_status_view_path: Incomplete
    parse_parental_status_view_path: Incomplete
    payments_account_path: Incomplete
    parse_payments_account_path: Incomplete
    performance_max_placement_view_path: Incomplete
    parse_performance_max_placement_view_path: Incomplete
    per_store_view_path: Incomplete
    parse_per_store_view_path: Incomplete
    product_category_constant_path: Incomplete
    parse_product_category_constant_path: Incomplete
    product_group_view_path: Incomplete
    parse_product_group_view_path: Incomplete
    product_link_path: Incomplete
    parse_product_link_path: Incomplete
    product_link_invitation_path: Incomplete
    parse_product_link_invitation_path: Incomplete
    qualifying_question_path: Incomplete
    parse_qualifying_question_path: Incomplete
    recommendation_path: Incomplete
    parse_recommendation_path: Incomplete
    recommendation_subscription_path: Incomplete
    parse_recommendation_subscription_path: Incomplete
    remarketing_action_path: Incomplete
    parse_remarketing_action_path: Incomplete
    search_term_view_path: Incomplete
    parse_search_term_view_path: Incomplete
    shared_criterion_path: Incomplete
    parse_shared_criterion_path: Incomplete
    shared_set_path: Incomplete
    parse_shared_set_path: Incomplete
    shopping_performance_view_path: Incomplete
    parse_shopping_performance_view_path: Incomplete
    shopping_product_path: Incomplete
    parse_shopping_product_path: Incomplete
    smart_campaign_search_term_view_path: Incomplete
    parse_smart_campaign_search_term_view_path: Incomplete
    smart_campaign_setting_path: Incomplete
    parse_smart_campaign_setting_path: Incomplete
    targeting_expansion_view_path: Incomplete
    parse_targeting_expansion_view_path: Incomplete
    third_party_app_analytics_link_path: Incomplete
    parse_third_party_app_analytics_link_path: Incomplete
    topic_constant_path: Incomplete
    parse_topic_constant_path: Incomplete
    topic_view_path: Incomplete
    parse_topic_view_path: Incomplete
    travel_activity_group_view_path: Incomplete
    parse_travel_activity_group_view_path: Incomplete
    travel_activity_performance_view_path: Incomplete
    parse_travel_activity_performance_view_path: Incomplete
    user_interest_path: Incomplete
    parse_user_interest_path: Incomplete
    user_list_path: Incomplete
    parse_user_list_path: Incomplete
    user_list_customer_type_path: Incomplete
    parse_user_list_customer_type_path: Incomplete
    user_location_view_path: Incomplete
    parse_user_location_view_path: Incomplete
    video_path: Incomplete
    parse_video_path: Incomplete
    webpage_view_path: Incomplete
    parse_webpage_view_path: Incomplete
    common_billing_account_path: Incomplete
    parse_common_billing_account_path: Incomplete
    common_folder_path: Incomplete
    parse_common_folder_path: Incomplete
    common_organization_path: Incomplete
    parse_common_organization_path: Incomplete
    common_project_path: Incomplete
    parse_common_project_path: Incomplete
    common_location_path: Incomplete
    parse_common_location_path: Incomplete
    @classmethod
    def from_service_account_info(cls, info: dict, *args, **kwargs): ...
    @classmethod
    def from_service_account_file(cls, filename: str, *args, **kwargs): ...
    from_service_account_json = from_service_account_file
    @classmethod
    def get_mtls_endpoint_and_cert_source(
        cls, client_options: ClientOptions | None = None
    ): ...
    @property
    def transport(self) -> GoogleAdsServiceTransport: ...
    @property
    def api_endpoint(self): ...
    @property
    def universe_domain(self) -> str: ...
    get_transport_class: Incomplete
    def __init__(
        self,
        *,
        credentials: ga_credentials.Credentials | None = None,
        transport: str
        | GoogleAdsServiceTransport
        | Callable[..., GoogleAdsServiceTransport]
        | None = "grpc_asyncio",
        client_options: ClientOptions | None = None,
        client_info: gapic_v1.client_info.ClientInfo = ...,
    ) -> None: ...
    async def search(
        self,
        request: google_ads_service.SearchGoogleAdsRequest | dict | None = None,
        *,
        customer_id: str | None = None,
        query: str | None = None,
        retry: retries.AsyncRetry | gapic_v1.method._MethodDefault = ...,
        timeout: float | object = ...,
        metadata: Sequence[tuple[str, str | bytes]] = (),
    ) -> pagers.SearchAsyncPager: ...
    def search_stream(
        self,
        request: google_ads_service.SearchGoogleAdsStreamRequest | dict | None = None,
        *,
        customer_id: str | None = None,
        query: str | None = None,
        retry: retries.AsyncRetry | gapic_v1.method._MethodDefault = ...,
        timeout: float | object = ...,
        metadata: Sequence[tuple[str, str | bytes]] = (),
    ) -> Awaitable[AsyncIterable[google_ads_service.SearchGoogleAdsStreamResponse]]: ...
    async def mutate(
        self,
        request: google_ads_service.MutateGoogleAdsRequest | dict | None = None,
        *,
        customer_id: str | None = None,
        mutate_operations: MutableSequence[google_ads_service.MutateOperation]
        | None = None,
        retry: retries.AsyncRetry | gapic_v1.method._MethodDefault = ...,
        timeout: float | object = ...,
        metadata: Sequence[tuple[str, str | bytes]] = (),
    ) -> google_ads_service.MutateGoogleAdsResponse: ...
    async def __aenter__(self) -> GoogleAdsServiceAsyncClient: ...
    async def __aexit__(self, exc_type, exc, tb) -> None: ...



from .async_client import IncentiveServiceAsyncClient as IncentiveServiceAsyncClient
from .client import IncentiveServiceClient as IncentiveServiceClient

__all__ = ["IncentiveServiceClient", "IncentiveServiceAsyncClient"]



from .base import RecommendationServiceTransport as RecommendationServiceTransport
from .grpc import (
    RecommendationServiceGrpcTransport as RecommendationServiceGrpcTransport,
)
from .grpc_asyncio import (
    RecommendationServiceGrpcAsyncIOTransport as RecommendationServiceGrpcAsyncIOTransport,
)

__all__ = [
    "RecommendationServiceTransport",
    "RecommendationServiceGrpcTransport",
    "RecommendationServiceGrpcAsyncIOTransport",
]



from .async_client import (
    GoogleAdsFieldServiceAsyncClient as GoogleAdsFieldServiceAsyncClient,
)
from .client import GoogleAdsFieldServiceClient as GoogleAdsFieldServiceClient

__all__ = ["GoogleAdsFieldServiceClient", "GoogleAdsFieldServiceAsyncClient"]



from .async_client import (
    CampaignLifecycleGoalServiceAsyncClient as CampaignLifecycleGoalServiceAsyncClient,
)
from .client import (
    CampaignLifecycleGoalServiceClient as CampaignLifecycleGoalServiceClient,
)

__all__ = [
    "CampaignLifecycleGoalServiceClient",
    "CampaignLifecycleGoalServiceAsyncClient",
]



from .base import GoalServiceTransport as GoalServiceTransport
from .grpc import GoalServiceGrpcTransport as GoalServiceGrpcTransport
from .grpc_asyncio import (
    GoalServiceGrpcAsyncIOTransport as GoalServiceGrpcAsyncIOTransport,
)

__all__ = [
    "GoalServiceTransport",
    "GoalServiceGrpcTransport",
    "GoalServiceGrpcAsyncIOTransport",
]



from .async_client import AdGroupAdServiceAsyncClient as AdGroupAdServiceAsyncClient
from .client import AdGroupAdServiceClient as AdGroupAdServiceClient

__all__ = ["AdGroupAdServiceClient", "AdGroupAdServiceAsyncClient"]



from collections.abc import Mapping
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

from google.ads.googleads.v23.enums.types.incentive_state import IncentiveStateEnum

_M = TypeVar("_M")

class AppliedIncentive(proto.Message):
    resource_name: str
    coupon_code: str
    incentive_state: IncentiveStateEnum.IncentiveState
    redemption_date_time: str
    fulfillment_expiration_date_time: str
    reward_grant_date_time: str
    reward_expiration_date_time: str
    currency_code: str
    reward_amount_micros: int
    granted_amount_micros: int
    required_min_spend_micros: int
    current_spend_towards_fulfillment_micros: int
    reward_balance_remaining_micros: int
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        resource_name: str = ...,
        coupon_code: str = ...,
        incentive_state: IncentiveStateEnum.IncentiveState = ...,
        redemption_date_time: str = ...,
        fulfillment_expiration_date_time: str = ...,
        reward_grant_date_time: str = ...,
        reward_expiration_date_time: str = ...,
        currency_code: str = ...,
        reward_amount_micros: int = ...,
        granted_amount_micros: int = ...,
        required_min_spend_micros: int = ...,
        current_spend_towards_fulfillment_micros: int = ...,
        reward_balance_remaining_micros: int = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "resource_name",
            "coupon_code",
            "incentive_state",
            "redemption_date_time",
            "fulfillment_expiration_date_time",
            "reward_grant_date_time",
            "reward_expiration_date_time",
            "currency_code",
            "reward_amount_micros",
            "granted_amount_micros",
            "required_min_spend_micros",
            "current_spend_towards_fulfillment_micros",
            "reward_balance_remaining_micros",
        ],
    ) -> bool: ...



from typing import Any, AsyncIterator, Awaitable, Callable, Iterator, Sequence

from _typeshed import Incomplete

from google.ads.googleads.v22.services.types import batch_job_service

OptionalRetry: Incomplete
OptionalAsyncRetry: Incomplete

class ListBatchJobResultsPager:
    def __init__(
        self,
        method: Callable[..., batch_job_service.ListBatchJobResultsResponse],
        request: batch_job_service.ListBatchJobResultsRequest,
        response: batch_job_service.ListBatchJobResultsResponse,
        *,
        retry: OptionalRetry = ...,
        timeout: float | object = ...,
        metadata: Sequence[tuple[str, str | bytes]] = (),
    ) -> None: ...
    def __getattr__(self, name: str) -> Any: ...
    @property
    def pages(self) -> Iterator[batch_job_service.ListBatchJobResultsResponse]: ...
    def __iter__(self) -> Iterator[batch_job_service.BatchJobResult]: ...

class ListBatchJobResultsAsyncPager:
    def __init__(
        self,
        method: Callable[..., Awaitable[batch_job_service.ListBatchJobResultsResponse]],
        request: batch_job_service.ListBatchJobResultsRequest,
        response: batch_job_service.ListBatchJobResultsResponse,
        *,
        retry: OptionalAsyncRetry = ...,
        timeout: float | object = ...,
        metadata: Sequence[tuple[str, str | bytes]] = (),
    ) -> None: ...
    def __getattr__(self, name: str) -> Any: ...
    @property
    async def pages(
        self,
    ) -> AsyncIterator[batch_job_service.ListBatchJobResultsResponse]: ...
    def __aiter__(self) -> AsyncIterator[batch_job_service.BatchJobResult]: ...



from collections.abc import Mapping, MutableSequence
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from google.rpc.status_pb2 import Status
from typing_extensions import Literal

_M = TypeVar("_M")

class AssetGroupIdentifier(proto.Message):
    asset_group_id: int
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        asset_group_id: int = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["asset_group_id"]
    ) -> bool: ...

class GenerateShareablePreviewsRequest(proto.Message):
    customer_id: str
    shareable_previews: MutableSequence[ShareablePreview]
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        customer_id: str = ...,
        shareable_previews: MutableSequence[ShareablePreview] = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["customer_id", "shareable_previews"]
    ) -> bool: ...

class GenerateShareablePreviewsResponse(proto.Message):
    responses: MutableSequence[ShareablePreviewOrError]
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        responses: MutableSequence[ShareablePreviewOrError] = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["responses"]
    ) -> bool: ...

class ShareablePreview(proto.Message):
    asset_group_identifier: AssetGroupIdentifier
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        asset_group_identifier: AssetGroupIdentifier = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["asset_group_identifier"]
    ) -> bool: ...

class ShareablePreviewOrError(proto.Message):
    asset_group_identifier: AssetGroupIdentifier
    shareable_preview_result: ShareablePreviewResult
    partial_failure_error: Status
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        asset_group_identifier: AssetGroupIdentifier = ...,
        shareable_preview_result: ShareablePreviewResult = ...,
        partial_failure_error: Status = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "asset_group_identifier",
            "shareable_preview_result",
            "partial_failure_error",
        ],
    ) -> bool: ...

class ShareablePreviewResult(proto.Message):
    shareable_preview_url: str
    expiration_date_time: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        shareable_preview_url: str = ...,
        expiration_date_time: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["shareable_preview_url", "expiration_date_time"]
    ) -> bool: ...



from collections.abc import Mapping, MutableSequence
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

from google.ads.googleads.v23.enums.types.custom_audience_member_type import (
    CustomAudienceMemberTypeEnum,
)
from google.ads.googleads.v23.enums.types.custom_audience_status import (
    CustomAudienceStatusEnum,
)
from google.ads.googleads.v23.enums.types.custom_audience_type import (
    CustomAudienceTypeEnum,
)

_M = TypeVar("_M")

class CustomAudience(proto.Message):
    resource_name: str
    id: int
    status: CustomAudienceStatusEnum.CustomAudienceStatus
    name: str
    type_: CustomAudienceTypeEnum.CustomAudienceType
    description: str
    members: MutableSequence[CustomAudienceMember]
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        resource_name: str = ...,
        id: int = ...,
        status: CustomAudienceStatusEnum.CustomAudienceStatus = ...,
        name: str = ...,
        type_: CustomAudienceTypeEnum.CustomAudienceType = ...,
        description: str = ...,
        members: MutableSequence[CustomAudienceMember] = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "resource_name", "id", "status", "name", "type_", "description", "members"
        ],
    ) -> bool: ...

class CustomAudienceMember(proto.Message):
    member_type: CustomAudienceMemberTypeEnum.CustomAudienceMemberType
    keyword: str
    url: str
    place_category: int
    app: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        member_type: CustomAudienceMemberTypeEnum.CustomAudienceMemberType = ...,
        keyword: str = ...,
        url: str = ...,
        place_category: int = ...,
        app: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["member_type", "keyword", "url", "place_category", "app"]
    ) -> bool: ...



from .async_client import GoogleAdsServiceAsyncClient as GoogleAdsServiceAsyncClient
from .client import GoogleAdsServiceClient as GoogleAdsServiceClient

__all__ = ["GoogleAdsServiceClient", "GoogleAdsServiceAsyncClient"]



from collections.abc import Mapping, MutableSequence
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from google.protobuf.field_mask_pb2 import FieldMask
from google.rpc.status_pb2 import Status
from typing_extensions import Literal

from google.ads.googleads.v23.enums.types.response_content_type import (
    ResponseContentTypeEnum,
)
from google.ads.googleads.v23.resources.types.conversion_action import ConversionAction

_M = TypeVar("_M")

class ConversionActionOperation(proto.Message):
    update_mask: FieldMask
    create: ConversionAction
    update: ConversionAction
    remove: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        update_mask: FieldMask = ...,
        create: ConversionAction = ...,
        update: ConversionAction = ...,
        remove: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["update_mask", "create", "update", "remove"]
    ) -> bool: ...

class MutateConversionActionResult(proto.Message):
    resource_name: str
    conversion_action: ConversionAction
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        resource_name: str = ...,
        conversion_action: ConversionAction = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["resource_name", "conversion_action"]
    ) -> bool: ...

class MutateConversionActionsRequest(proto.Message):
    customer_id: str
    operations: MutableSequence[ConversionActionOperation]
    partial_failure: bool
    validate_only: bool
    response_content_type: ResponseContentTypeEnum.ResponseContentType
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        customer_id: str = ...,
        operations: MutableSequence[ConversionActionOperation] = ...,
        partial_failure: bool = ...,
        validate_only: bool = ...,
        response_content_type: ResponseContentTypeEnum.ResponseContentType = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "customer_id",
            "operations",
            "partial_failure",
            "validate_only",
            "response_content_type",
        ],
    ) -> bool: ...

class MutateConversionActionsResponse(proto.Message):
    partial_failure_error: Status
    results: MutableSequence[MutateConversionActionResult]
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        partial_failure_error: Status = ...,
        results: MutableSequence[MutateConversionActionResult] = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["partial_failure_error", "results"]
    ) -> bool: ...



from .async_client import CampaignServiceAsyncClient as CampaignServiceAsyncClient
from .client import CampaignServiceClient as CampaignServiceClient

__all__ = ["CampaignServiceClient", "CampaignServiceAsyncClient"]



from .async_client import (
    CampaignCriterionServiceAsyncClient as CampaignCriterionServiceAsyncClient,
)
from .client import CampaignCriterionServiceClient as CampaignCriterionServiceClient

__all__ = ["CampaignCriterionServiceClient", "CampaignCriterionServiceAsyncClient"]



from .async_client import (
    SmartCampaignSuggestServiceAsyncClient as SmartCampaignSuggestServiceAsyncClient,
)
from .client import (
    SmartCampaignSuggestServiceClient as SmartCampaignSuggestServiceClient,
)

__all__ = [
    "SmartCampaignSuggestServiceClient",
    "SmartCampaignSuggestServiceAsyncClient",
]



from collections.abc import Mapping, MutableSequence
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

from google.ads.googleads.v20.enums.types.product_availability import (
    ProductAvailabilityEnum,
)
from google.ads.googleads.v20.enums.types.product_channel import ProductChannelEnum
from google.ads.googleads.v20.enums.types.product_channel_exclusivity import (
    ProductChannelExclusivityEnum,
)
from google.ads.googleads.v20.enums.types.product_condition import ProductConditionEnum
from google.ads.googleads.v20.enums.types.product_issue_severity import (
    ProductIssueSeverityEnum,
)
from google.ads.googleads.v20.enums.types.product_status import ProductStatusEnum

_M = TypeVar("_M")

class ShoppingProduct(proto.Message):
    class ProductIssue(proto.Message):
        error_code: str
        ads_severity: ProductIssueSeverityEnum.ProductIssueSeverity
        attribute_name: str
        description: str
        detail: str
        documentation: str
        affected_regions: MutableSequence[str]
        def __init__(
            self: _M,
            mapping: _M | Mapping | google.protobuf.message.Message | None = None,
            *,
            ignore_unknown_fields: bool = False,
            error_code: str = ...,
            ads_severity: ProductIssueSeverityEnum.ProductIssueSeverity = ...,
            attribute_name: str = ...,
            description: str = ...,
            detail: str = ...,
            documentation: str = ...,
            affected_regions: MutableSequence[str] = ...,
        ) -> None: ...
        def __contains__(  # type: ignore[override]
            self,
            key: Literal[
                "error_code",
                "ads_severity",
                "attribute_name",
                "description",
                "detail",
                "documentation",
                "affected_regions",
            ],
        ) -> bool: ...

    resource_name: str
    merchant_center_id: int
    channel: ProductChannelEnum.ProductChannel
    language_code: str
    feed_label: str
    item_id: str
    multi_client_account_id: int
    title: str
    brand: str
    price_micros: int
    currency_code: str
    channel_exclusivity: ProductChannelExclusivityEnum.ProductChannelExclusivity
    condition: ProductConditionEnum.ProductCondition
    availability: ProductAvailabilityEnum.ProductAvailability
    target_countries: MutableSequence[str]
    custom_attribute0: str
    custom_attribute1: str
    custom_attribute2: str
    custom_attribute3: str
    custom_attribute4: str
    category_level1: str
    category_level2: str
    category_level3: str
    category_level4: str
    category_level5: str
    product_type_level1: str
    product_type_level2: str
    product_type_level3: str
    product_type_level4: str
    product_type_level5: str
    effective_max_cpc_micros: int
    status: ProductStatusEnum.ProductStatus
    issues: MutableSequence[ShoppingProduct.ProductIssue]
    campaign: str
    ad_group: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        resource_name: str = ...,
        merchant_center_id: int = ...,
        channel: ProductChannelEnum.ProductChannel = ...,
        language_code: str = ...,
        feed_label: str = ...,
        item_id: str = ...,
        multi_client_account_id: int = ...,
        title: str = ...,
        brand: str = ...,
        price_micros: int = ...,
        currency_code: str = ...,
        channel_exclusivity: ProductChannelExclusivityEnum.ProductChannelExclusivity = ...,
        condition: ProductConditionEnum.ProductCondition = ...,
        availability: ProductAvailabilityEnum.ProductAvailability = ...,
        target_countries: MutableSequence[str] = ...,
        custom_attribute0: str = ...,
        custom_attribute1: str = ...,
        custom_attribute2: str = ...,
        custom_attribute3: str = ...,
        custom_attribute4: str = ...,
        category_level1: str = ...,
        category_level2: str = ...,
        category_level3: str = ...,
        category_level4: str = ...,
        category_level5: str = ...,
        product_type_level1: str = ...,
        product_type_level2: str = ...,
        product_type_level3: str = ...,
        product_type_level4: str = ...,
        product_type_level5: str = ...,
        effective_max_cpc_micros: int = ...,
        status: ProductStatusEnum.ProductStatus = ...,
        issues: MutableSequence[ShoppingProduct.ProductIssue] = ...,
        campaign: str = ...,
        ad_group: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "resource_name",
            "merchant_center_id",
            "channel",
            "language_code",
            "feed_label",
            "item_id",
            "multi_client_account_id",
            "title",
            "brand",
            "price_micros",
            "currency_code",
            "channel_exclusivity",
            "condition",
            "availability",
            "target_countries",
            "custom_attribute0",
            "custom_attribute1",
            "custom_attribute2",
            "custom_attribute3",
            "custom_attribute4",
            "category_level1",
            "category_level2",
            "category_level3",
            "category_level4",
            "category_level5",
            "product_type_level1",
            "product_type_level2",
            "product_type_level3",
            "product_type_level4",
            "product_type_level5",
            "effective_max_cpc_micros",
            "status",
            "issues",
            "campaign",
            "ad_group",
        ],
    ) -> bool: ...



from .base import CampaignLabelServiceTransport as CampaignLabelServiceTransport
from .grpc import CampaignLabelServiceGrpcTransport as CampaignLabelServiceGrpcTransport
from .grpc_asyncio import (
    CampaignLabelServiceGrpcAsyncIOTransport as CampaignLabelServiceGrpcAsyncIOTransport,
)

__all__ = [
    "CampaignLabelServiceTransport",
    "CampaignLabelServiceGrpcTransport",
    "CampaignLabelServiceGrpcAsyncIOTransport",
]



from .base import (
    UserListCustomerTypeServiceTransport as UserListCustomerTypeServiceTransport,
)
from .grpc import (
    UserListCustomerTypeServiceGrpcTransport as UserListCustomerTypeServiceGrpcTransport,
)
from .grpc_asyncio import (
    UserListCustomerTypeServiceGrpcAsyncIOTransport as UserListCustomerTypeServiceGrpcAsyncIOTransport,
)

__all__ = [
    "UserListCustomerTypeServiceTransport",
    "UserListCustomerTypeServiceGrpcTransport",
    "UserListCustomerTypeServiceGrpcAsyncIOTransport",
]



from collections.abc import Mapping, MutableSequence
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

from google.ads.googleads.v22.resources.types.payments_account import PaymentsAccount

_M = TypeVar("_M")

class ListPaymentsAccountsRequest(proto.Message):
    customer_id: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        customer_id: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["customer_id"]
    ) -> bool: ...

class ListPaymentsAccountsResponse(proto.Message):
    payments_accounts: MutableSequence[PaymentsAccount]
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        payments_accounts: MutableSequence[PaymentsAccount] = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["payments_accounts"]
    ) -> bool: ...



from .base import CampaignBudgetServiceTransport as CampaignBudgetServiceTransport
from .grpc import (
    CampaignBudgetServiceGrpcTransport as CampaignBudgetServiceGrpcTransport,
)
from .grpc_asyncio import (
    CampaignBudgetServiceGrpcAsyncIOTransport as CampaignBudgetServiceGrpcAsyncIOTransport,
)

__all__ = [
    "CampaignBudgetServiceTransport",
    "CampaignBudgetServiceGrpcTransport",
    "CampaignBudgetServiceGrpcAsyncIOTransport",
]



from .async_client import CustomerServiceAsyncClient as CustomerServiceAsyncClient
from .client import CustomerServiceClient as CustomerServiceClient

__all__ = ["CustomerServiceClient", "CustomerServiceAsyncClient"]



from .async_client import (
    CustomConversionGoalServiceAsyncClient as CustomConversionGoalServiceAsyncClient,
)
from .client import (
    CustomConversionGoalServiceClient as CustomConversionGoalServiceClient,
)

__all__ = [
    "CustomConversionGoalServiceClient",
    "CustomConversionGoalServiceAsyncClient",
]



from .base import AdServiceTransport as AdServiceTransport
from .grpc import AdServiceGrpcTransport as AdServiceGrpcTransport
from .grpc_asyncio import AdServiceGrpcAsyncIOTransport as AdServiceGrpcAsyncIOTransport

__all__ = [
    "AdServiceTransport",
    "AdServiceGrpcTransport",
    "AdServiceGrpcAsyncIOTransport",
]



from .base import GoogleAdsFieldServiceTransport as GoogleAdsFieldServiceTransport
from .grpc import (
    GoogleAdsFieldServiceGrpcTransport as GoogleAdsFieldServiceGrpcTransport,
)
from .grpc_asyncio import (
    GoogleAdsFieldServiceGrpcAsyncIOTransport as GoogleAdsFieldServiceGrpcAsyncIOTransport,
)

__all__ = [
    "GoogleAdsFieldServiceTransport",
    "GoogleAdsFieldServiceGrpcTransport",
    "GoogleAdsFieldServiceGrpcAsyncIOTransport",
]



from .async_client import (
    ConversionUploadServiceAsyncClient as ConversionUploadServiceAsyncClient,
)
from .client import ConversionUploadServiceClient as ConversionUploadServiceClient

__all__ = ["ConversionUploadServiceClient", "ConversionUploadServiceAsyncClient"]



from .base import CustomInterestServiceTransport as CustomInterestServiceTransport
from .grpc import (
    CustomInterestServiceGrpcTransport as CustomInterestServiceGrpcTransport,
)
from .grpc_asyncio import (
    CustomInterestServiceGrpcAsyncIOTransport as CustomInterestServiceGrpcAsyncIOTransport,
)

__all__ = [
    "CustomInterestServiceTransport",
    "CustomInterestServiceGrpcTransport",
    "CustomInterestServiceGrpcAsyncIOTransport",
]



from collections.abc import Mapping, MutableSequence
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

from google.ads.googleads.v23.enums.types.offline_conversion_diagnostic_status_enum import (
    OfflineConversionDiagnosticStatusEnum,
)
from google.ads.googleads.v23.enums.types.offline_event_upload_client_enum import (
    OfflineEventUploadClientEnum,
)
from google.ads.googleads.v23.resources.types.offline_conversion_upload_client_summary import (
    OfflineConversionAlert,
    OfflineConversionSummary,
)

_M = TypeVar("_M")

class OfflineConversionUploadConversionActionSummary(proto.Message):
    resource_name: str
    client: OfflineEventUploadClientEnum.OfflineEventUploadClient
    conversion_action_id: int
    conversion_action_name: str
    status: OfflineConversionDiagnosticStatusEnum.OfflineConversionDiagnosticStatus
    total_event_count: int
    successful_event_count: int
    pending_event_count: int
    last_upload_date_time: str
    daily_summaries: MutableSequence[OfflineConversionSummary]
    job_summaries: MutableSequence[OfflineConversionSummary]
    alerts: MutableSequence[OfflineConversionAlert]
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        resource_name: str = ...,
        client: OfflineEventUploadClientEnum.OfflineEventUploadClient = ...,
        conversion_action_id: int = ...,
        conversion_action_name: str = ...,
        status: OfflineConversionDiagnosticStatusEnum.OfflineConversionDiagnosticStatus = ...,
        total_event_count: int = ...,
        successful_event_count: int = ...,
        pending_event_count: int = ...,
        last_upload_date_time: str = ...,
        daily_summaries: MutableSequence[OfflineConversionSummary] = ...,
        job_summaries: MutableSequence[OfflineConversionSummary] = ...,
        alerts: MutableSequence[OfflineConversionAlert] = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "resource_name",
            "client",
            "conversion_action_id",
            "conversion_action_name",
            "status",
            "total_event_count",
            "successful_event_count",
            "pending_event_count",
            "last_upload_date_time",
            "daily_summaries",
            "job_summaries",
            "alerts",
        ],
    ) -> bool: ...



from collections.abc import Mapping, MutableSequence
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

_M = TypeVar("_M")

class TopicConstant(proto.Message):
    resource_name: str
    id: int
    topic_constant_parent: str
    path: MutableSequence[str]
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        resource_name: str = ...,
        id: int = ...,
        topic_constant_parent: str = ...,
        path: MutableSequence[str] = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["resource_name", "id", "topic_constant_parent", "path"]
    ) -> bool: ...



from .base import (
    AdGroupCriterionCustomizerServiceTransport as AdGroupCriterionCustomizerServiceTransport,
)
from .grpc import (
    AdGroupCriterionCustomizerServiceGrpcTransport as AdGroupCriterionCustomizerServiceGrpcTransport,
)
from .grpc_asyncio import (
    AdGroupCriterionCustomizerServiceGrpcAsyncIOTransport as AdGroupCriterionCustomizerServiceGrpcAsyncIOTransport,
)

__all__ = [
    "AdGroupCriterionCustomizerServiceTransport",
    "AdGroupCriterionCustomizerServiceGrpcTransport",
    "AdGroupCriterionCustomizerServiceGrpcAsyncIOTransport",
]



from .base import (
    ConversionValueRuleSetServiceTransport as ConversionValueRuleSetServiceTransport,
)
from .grpc import (
    ConversionValueRuleSetServiceGrpcTransport as ConversionValueRuleSetServiceGrpcTransport,
)
from .grpc_asyncio import (
    ConversionValueRuleSetServiceGrpcAsyncIOTransport as ConversionValueRuleSetServiceGrpcAsyncIOTransport,
)

__all__ = [
    "ConversionValueRuleSetServiceTransport",
    "ConversionValueRuleSetServiceGrpcTransport",
    "ConversionValueRuleSetServiceGrpcAsyncIOTransport",
]



from collections.abc import Mapping
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

_M = TypeVar("_M")

class AdCustomizerErrorEnum(proto.Message):
    class AdCustomizerError(proto.Enum):
        UNSPECIFIED = 0
        UNKNOWN = 1
        COUNTDOWN_INVALID_DATE_FORMAT = 2
        COUNTDOWN_DATE_IN_PAST = 3
        COUNTDOWN_INVALID_LOCALE = 4
        COUNTDOWN_INVALID_START_DAYS_BEFORE = 5
        UNKNOWN_USER_LIST = 6

    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: NoReturn
    ) -> bool: ...



from .base import AudienceServiceTransport as AudienceServiceTransport
from .grpc import AudienceServiceGrpcTransport as AudienceServiceGrpcTransport
from .grpc_asyncio import (
    AudienceServiceGrpcAsyncIOTransport as AudienceServiceGrpcAsyncIOTransport,
)

__all__ = [
    "AudienceServiceTransport",
    "AudienceServiceGrpcTransport",
    "AudienceServiceGrpcAsyncIOTransport",
]



from .async_client import (
    CampaignBudgetServiceAsyncClient as CampaignBudgetServiceAsyncClient,
)
from .client import CampaignBudgetServiceClient as CampaignBudgetServiceClient

__all__ = ["CampaignBudgetServiceClient", "CampaignBudgetServiceAsyncClient"]



from .async_client import (
    CampaignCustomizerServiceAsyncClient as CampaignCustomizerServiceAsyncClient,
)
from .client import CampaignCustomizerServiceClient as CampaignCustomizerServiceClient

__all__ = ["CampaignCustomizerServiceClient", "CampaignCustomizerServiceAsyncClient"]



from collections.abc import Mapping, MutableSequence
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

from google.ads.googleads.v23.common.types.bidding import (
    Commission,
    FixedCpm,
    ManualCpa,
    ManualCpc,
    ManualCpm,
    ManualCpv,
    MaximizeConversions,
    MaximizeConversionValue,
    PercentCpc,
    TargetCpa,
    TargetCpc,
    TargetCpm,
    TargetCpv,
    TargetImpressionShare,
    TargetRoas,
    TargetSpend,
)
from google.ads.googleads.v23.common.types.custom_parameter import CustomParameter
from google.ads.googleads.v23.common.types.frequency_cap import FrequencyCapEntry
from google.ads.googleads.v23.common.types.real_time_bidding_setting import (
    RealTimeBiddingSetting,
)
from google.ads.googleads.v23.common.types.targeting_setting import TargetingSetting
from google.ads.googleads.v23.common.types.third_party_integration_partners import (
    CampaignThirdPartyIntegrationPartners,
)
from google.ads.googleads.v23.enums.types.ad_group_type import AdGroupTypeEnum
from google.ads.googleads.v23.enums.types.ad_serving_optimization_status import (
    AdServingOptimizationStatusEnum,
)
from google.ads.googleads.v23.enums.types.advertising_channel_sub_type import (
    AdvertisingChannelSubTypeEnum,
)
from google.ads.googleads.v23.enums.types.advertising_channel_type import (
    AdvertisingChannelTypeEnum,
)
from google.ads.googleads.v23.enums.types.app_campaign_app_store import (
    AppCampaignAppStoreEnum,
)
from google.ads.googleads.v23.enums.types.app_campaign_bidding_strategy_goal_type import (
    AppCampaignBiddingStrategyGoalTypeEnum,
)
from google.ads.googleads.v23.enums.types.asset_automation_status import (
    AssetAutomationStatusEnum,
)
from google.ads.googleads.v23.enums.types.asset_automation_type import (
    AssetAutomationTypeEnum,
)
from google.ads.googleads.v23.enums.types.asset_field_type import AssetFieldTypeEnum
from google.ads.googleads.v23.enums.types.asset_set_type import AssetSetTypeEnum
from google.ads.googleads.v23.enums.types.bidding_strategy_system_status import (
    BiddingStrategySystemStatusEnum,
)
from google.ads.googleads.v23.enums.types.bidding_strategy_type import (
    BiddingStrategyTypeEnum,
)
from google.ads.googleads.v23.enums.types.brand_safety_suitability import (
    BrandSafetySuitabilityEnum,
)
from google.ads.googleads.v23.enums.types.campaign_experiment_type import (
    CampaignExperimentTypeEnum,
)
from google.ads.googleads.v23.enums.types.campaign_keyword_match_type import (
    CampaignKeywordMatchTypeEnum,
)
from google.ads.googleads.v23.enums.types.campaign_primary_status import (
    CampaignPrimaryStatusEnum,
)
from google.ads.googleads.v23.enums.types.campaign_primary_status_reason import (
    CampaignPrimaryStatusReasonEnum,
)
from google.ads.googleads.v23.enums.types.campaign_serving_status import (
    CampaignServingStatusEnum,
)
from google.ads.googleads.v23.enums.types.campaign_status import CampaignStatusEnum
from google.ads.googleads.v23.enums.types.eu_political_advertising_status import (
    EuPoliticalAdvertisingStatusEnum,
)
from google.ads.googleads.v23.enums.types.listing_type import ListingTypeEnum
from google.ads.googleads.v23.enums.types.location_source_type import (
    LocationSourceTypeEnum,
)
from google.ads.googleads.v23.enums.types.negative_geo_target_type import (
    NegativeGeoTargetTypeEnum,
)
from google.ads.googleads.v23.enums.types.non_skippable_max_duration import (
    NonSkippableMaxDurationEnum,
)
from google.ads.googleads.v23.enums.types.non_skippable_min_duration import (
    NonSkippableMinDurationEnum,
)
from google.ads.googleads.v23.enums.types.optimization_goal_type import (
    OptimizationGoalTypeEnum,
)
from google.ads.googleads.v23.enums.types.payment_mode import PaymentModeEnum
from google.ads.googleads.v23.enums.types.performance_max_upgrade_status import (
    PerformanceMaxUpgradeStatusEnum,
)
from google.ads.googleads.v23.enums.types.positive_geo_target_type import (
    PositiveGeoTargetTypeEnum,
)
from google.ads.googleads.v23.enums.types.vanity_pharma_display_url_mode import (
    VanityPharmaDisplayUrlModeEnum,
)
from google.ads.googleads.v23.enums.types.vanity_pharma_text import VanityPharmaTextEnum
from google.ads.googleads.v23.enums.types.video_ad_format_restriction import (
    VideoAdFormatRestrictionEnum,
)
from google.ads.googleads.v23.enums.types.video_ad_sequence_interaction_type import (
    VideoAdSequenceInteractionTypeEnum,
)
from google.ads.googleads.v23.enums.types.video_ad_sequence_minimum_duration import (
    VideoAdSequenceMinimumDurationEnum,
)

_M = TypeVar("_M")

class Campaign(proto.Message):
    class AiMaxSetting(proto.Message):
        class AiMaxBundlingRequired(proto.Enum):
            UNSPECIFIED = 0
            UNKNOWN = 1
            NOT_REQUIRED = 2
            REQUIRED = 3

        enable_ai_max: bool
        bundling_required: Campaign.AiMaxSetting.AiMaxBundlingRequired
        def __init__(
            self: _M,
            mapping: _M | Mapping | google.protobuf.message.Message | None = None,
            *,
            ignore_unknown_fields: bool = False,
            enable_ai_max: bool = ...,
            bundling_required: Campaign.AiMaxSetting.AiMaxBundlingRequired = ...,
        ) -> None: ...
        def __contains__(  # type: ignore[override]
            self, key: Literal["enable_ai_max", "bundling_required"]
        ) -> bool: ...

    class AppCampaignSetting(proto.Message):
        bidding_strategy_goal_type: (
            AppCampaignBiddingStrategyGoalTypeEnum.AppCampaignBiddingStrategyGoalType
        )
        app_id: str
        app_store: AppCampaignAppStoreEnum.AppCampaignAppStore
        def __init__(
            self: _M,
            mapping: _M | Mapping | google.protobuf.message.Message | None = None,
            *,
            ignore_unknown_fields: bool = False,
            bidding_strategy_goal_type: AppCampaignBiddingStrategyGoalTypeEnum.AppCampaignBiddingStrategyGoalType = ...,
            app_id: str = ...,
            app_store: AppCampaignAppStoreEnum.AppCampaignAppStore = ...,
        ) -> None: ...
        def __contains__(  # type: ignore[override]
            self, key: Literal["bidding_strategy_goal_type", "app_id", "app_store"]
        ) -> bool: ...

    class AssetAutomationSetting(proto.Message):
        asset_automation_type: AssetAutomationTypeEnum.AssetAutomationType
        asset_automation_status: AssetAutomationStatusEnum.AssetAutomationStatus
        def __init__(
            self: _M,
            mapping: _M | Mapping | google.protobuf.message.Message | None = None,
            *,
            ignore_unknown_fields: bool = False,
            asset_automation_type: AssetAutomationTypeEnum.AssetAutomationType = ...,
            asset_automation_status: AssetAutomationStatusEnum.AssetAutomationStatus = ...,
        ) -> None: ...
        def __contains__(  # type: ignore[override]
            self, key: Literal["asset_automation_type", "asset_automation_status"]
        ) -> bool: ...

    class AudienceSetting(proto.Message):
        use_audience_grouped: bool
        def __init__(
            self: _M,
            mapping: _M | Mapping | google.protobuf.message.Message | None = None,
            *,
            ignore_unknown_fields: bool = False,
            use_audience_grouped: bool = ...,
        ) -> None: ...
        def __contains__(  # type: ignore[override]
            self, key: Literal["use_audience_grouped"]
        ) -> bool: ...

    class BrandGuidelines(proto.Message):
        main_color: str
        accent_color: str
        predefined_font_family: str
        def __init__(
            self: _M,
            mapping: _M | Mapping | google.protobuf.message.Message | None = None,
            *,
            ignore_unknown_fields: bool = False,
            main_color: str = ...,
            accent_color: str = ...,
            predefined_font_family: str = ...,
        ) -> None: ...
        def __contains__(  # type: ignore[override]
            self, key: Literal["main_color", "accent_color", "predefined_font_family"]
        ) -> bool: ...

    class CategoryBid(proto.Message):
        category_id: str
        manual_cpa_bid_micros: int
        target_cpa_bid_micros: int
        def __init__(
            self: _M,
            mapping: _M | Mapping | google.protobuf.message.Message | None = None,
            *,
            ignore_unknown_fields: bool = False,
            category_id: str = ...,
            manual_cpa_bid_micros: int = ...,
            target_cpa_bid_micros: int = ...,
        ) -> None: ...
        def __contains__(  # type: ignore[override]
            self,
            key: Literal[
                "category_id", "manual_cpa_bid_micros", "target_cpa_bid_micros"
            ],
        ) -> bool: ...

    class DemandGenCampaignSettings(proto.Message):
        upgraded_targeting: bool
        def __init__(
            self: _M,
            mapping: _M | Mapping | google.protobuf.message.Message | None = None,
            *,
            ignore_unknown_fields: bool = False,
            upgraded_targeting: bool = ...,
        ) -> None: ...
        def __contains__(  # type: ignore[override]
            self, key: Literal["upgraded_targeting"]
        ) -> bool: ...

    class DynamicSearchAdsSetting(proto.Message):
        domain_name: str
        language_code: str
        use_supplied_urls_only: bool
        def __init__(
            self: _M,
            mapping: _M | Mapping | google.protobuf.message.Message | None = None,
            *,
            ignore_unknown_fields: bool = False,
            domain_name: str = ...,
            language_code: str = ...,
            use_supplied_urls_only: bool = ...,
        ) -> None: ...
        def __contains__(  # type: ignore[override]
            self, key: Literal["domain_name", "language_code", "use_supplied_urls_only"]
        ) -> bool: ...

    class GeoTargetTypeSetting(proto.Message):
        positive_geo_target_type: PositiveGeoTargetTypeEnum.PositiveGeoTargetType
        negative_geo_target_type: NegativeGeoTargetTypeEnum.NegativeGeoTargetType
        def __init__(
            self: _M,
            mapping: _M | Mapping | google.protobuf.message.Message | None = None,
            *,
            ignore_unknown_fields: bool = False,
            positive_geo_target_type: PositiveGeoTargetTypeEnum.PositiveGeoTargetType = ...,
            negative_geo_target_type: NegativeGeoTargetTypeEnum.NegativeGeoTargetType = ...,
        ) -> None: ...
        def __contains__(  # type: ignore[override]
            self, key: Literal["positive_geo_target_type", "negative_geo_target_type"]
        ) -> bool: ...

    class HotelSettingInfo(proto.Message):
        hotel_center_id: int
        def __init__(
            self: _M,
            mapping: _M | Mapping | google.protobuf.message.Message | None = None,
            *,
            ignore_unknown_fields: bool = False,
            hotel_center_id: int = ...,
        ) -> None: ...
        def __contains__(  # type: ignore[override]
            self, key: Literal["hotel_center_id"]
        ) -> bool: ...

    class LocalCampaignSetting(proto.Message):
        location_source_type: LocationSourceTypeEnum.LocationSourceType
        def __init__(
            self: _M,
            mapping: _M | Mapping | google.protobuf.message.Message | None = None,
            *,
            ignore_unknown_fields: bool = False,
            location_source_type: LocationSourceTypeEnum.LocationSourceType = ...,
        ) -> None: ...
        def __contains__(  # type: ignore[override]
            self, key: Literal["location_source_type"]
        ) -> bool: ...

    class LocalServicesCampaignSettings(proto.Message):
        category_bids: MutableSequence[Campaign.CategoryBid]
        def __init__(
            self: _M,
            mapping: _M | Mapping | google.protobuf.message.Message | None = None,
            *,
            ignore_unknown_fields: bool = False,
            category_bids: MutableSequence[Campaign.CategoryBid] = ...,
        ) -> None: ...
        def __contains__(  # type: ignore[override]
            self, key: Literal["category_bids"]
        ) -> bool: ...

    class NetworkSettings(proto.Message):
        target_google_search: bool
        target_search_network: bool
        target_content_network: bool
        target_partner_search_network: bool
        target_youtube: bool
        target_google_tv_network: bool
        def __init__(
            self: _M,
            mapping: _M | Mapping | google.protobuf.message.Message | None = None,
            *,
            ignore_unknown_fields: bool = False,
            target_google_search: bool = ...,
            target_search_network: bool = ...,
            target_content_network: bool = ...,
            target_partner_search_network: bool = ...,
            target_youtube: bool = ...,
            target_google_tv_network: bool = ...,
        ) -> None: ...
        def __contains__(  # type: ignore[override]
            self,
            key: Literal[
                "target_google_search",
                "target_search_network",
                "target_content_network",
                "target_partner_search_network",
                "target_youtube",
                "target_google_tv_network",
            ],
        ) -> bool: ...

    class OptimizationGoalSetting(proto.Message):
        optimization_goal_types: MutableSequence[
            OptimizationGoalTypeEnum.OptimizationGoalType
        ]
        def __init__(
            self: _M,
            mapping: _M | Mapping | google.protobuf.message.Message | None = None,
            *,
            ignore_unknown_fields: bool = False,
            optimization_goal_types: MutableSequence[
                OptimizationGoalTypeEnum.OptimizationGoalType
            ] = ...,
        ) -> None: ...
        def __contains__(  # type: ignore[override]
            self, key: Literal["optimization_goal_types"]
        ) -> bool: ...

    class PerformanceMaxUpgrade(proto.Message):
        performance_max_campaign: str
        pre_upgrade_campaign: str
        status: PerformanceMaxUpgradeStatusEnum.PerformanceMaxUpgradeStatus
        def __init__(
            self: _M,
            mapping: _M | Mapping | google.protobuf.message.Message | None = None,
            *,
            ignore_unknown_fields: bool = False,
            performance_max_campaign: str = ...,
            pre_upgrade_campaign: str = ...,
            status: PerformanceMaxUpgradeStatusEnum.PerformanceMaxUpgradeStatus = ...,
        ) -> None: ...
        def __contains__(  # type: ignore[override]
            self,
            key: Literal["performance_max_campaign", "pre_upgrade_campaign", "status"],
        ) -> bool: ...

    class PmaxCampaignSettings(proto.Message):
        class BrandTargetingOverrides(proto.Message):
            ignore_exclusions_for_shopping_ads: bool
            def __init__(
                self: _M,
                mapping: _M | Mapping | google.protobuf.message.Message | None = None,
                *,
                ignore_unknown_fields: bool = False,
                ignore_exclusions_for_shopping_ads: bool = ...,
            ) -> None: ...
            def __contains__(  # type: ignore[override]
                self, key: Literal["ignore_exclusions_for_shopping_ads"]
            ) -> bool: ...

        brand_targeting_overrides: Campaign.PmaxCampaignSettings.BrandTargetingOverrides
        def __init__(
            self: _M,
            mapping: _M | Mapping | google.protobuf.message.Message | None = None,
            *,
            ignore_unknown_fields: bool = False,
            brand_targeting_overrides: Campaign.PmaxCampaignSettings.BrandTargetingOverrides = ...,
        ) -> None: ...
        def __contains__(  # type: ignore[override]
            self, key: Literal["brand_targeting_overrides"]
        ) -> bool: ...

    class SelectiveOptimization(proto.Message):
        conversion_actions: MutableSequence[str]
        def __init__(
            self: _M,
            mapping: _M | Mapping | google.protobuf.message.Message | None = None,
            *,
            ignore_unknown_fields: bool = False,
            conversion_actions: MutableSequence[str] = ...,
        ) -> None: ...
        def __contains__(  # type: ignore[override]
            self, key: Literal["conversion_actions"]
        ) -> bool: ...

    class ShoppingSetting(proto.Message):
        merchant_id: int
        feed_label: str
        campaign_priority: int
        enable_local: bool
        use_vehicle_inventory: bool
        advertising_partner_ids: MutableSequence[int]
        disable_product_feed: bool
        def __init__(
            self: _M,
            mapping: _M | Mapping | google.protobuf.message.Message | None = None,
            *,
            ignore_unknown_fields: bool = False,
            merchant_id: int = ...,
            feed_label: str = ...,
            campaign_priority: int = ...,
            enable_local: bool = ...,
            use_vehicle_inventory: bool = ...,
            advertising_partner_ids: MutableSequence[int] = ...,
            disable_product_feed: bool = ...,
        ) -> None: ...
        def __contains__(  # type: ignore[override]
            self,
            key: Literal[
                "merchant_id",
                "feed_label",
                "campaign_priority",
                "enable_local",
                "use_vehicle_inventory",
                "advertising_partner_ids",
                "disable_product_feed",
            ],
        ) -> bool: ...

    class TrackingSetting(proto.Message):
        tracking_url: str
        def __init__(
            self: _M,
            mapping: _M | Mapping | google.protobuf.message.Message | None = None,
            *,
            ignore_unknown_fields: bool = False,
            tracking_url: str = ...,
        ) -> None: ...
        def __contains__(  # type: ignore[override]
            self, key: Literal["tracking_url"]
        ) -> bool: ...

    class TravelCampaignSettings(proto.Message):
        travel_account_id: int
        def __init__(
            self: _M,
            mapping: _M | Mapping | google.protobuf.message.Message | None = None,
            *,
            ignore_unknown_fields: bool = False,
            travel_account_id: int = ...,
        ) -> None: ...
        def __contains__(  # type: ignore[override]
            self, key: Literal["travel_account_id"]
        ) -> bool: ...

    class VanityPharma(proto.Message):
        vanity_pharma_display_url_mode: (
            VanityPharmaDisplayUrlModeEnum.VanityPharmaDisplayUrlMode
        )
        vanity_pharma_text: VanityPharmaTextEnum.VanityPharmaText
        def __init__(
            self: _M,
            mapping: _M | Mapping | google.protobuf.message.Message | None = None,
            *,
            ignore_unknown_fields: bool = False,
            vanity_pharma_display_url_mode: VanityPharmaDisplayUrlModeEnum.VanityPharmaDisplayUrlMode = ...,
            vanity_pharma_text: VanityPharmaTextEnum.VanityPharmaText = ...,
        ) -> None: ...
        def __contains__(  # type: ignore[override]
            self, key: Literal["vanity_pharma_display_url_mode", "vanity_pharma_text"]
        ) -> bool: ...

    class VideoCampaignSettings(proto.Message):
        class NonSkippableInStreamRestrictions(proto.Message):
            min_duration: NonSkippableMinDurationEnum.NonSkippableMinDuration
            max_duration: NonSkippableMaxDurationEnum.NonSkippableMaxDuration
            def __init__(
                self: _M,
                mapping: _M | Mapping | google.protobuf.message.Message | None = None,
                *,
                ignore_unknown_fields: bool = False,
                min_duration: NonSkippableMinDurationEnum.NonSkippableMinDuration = ...,
                max_duration: NonSkippableMaxDurationEnum.NonSkippableMaxDuration = ...,
            ) -> None: ...
            def __contains__(  # type: ignore[override]
                self, key: Literal["min_duration", "max_duration"]
            ) -> bool: ...

        class VideoAdFormatControl(proto.Message):
            format_restriction: VideoAdFormatRestrictionEnum.VideoAdFormatRestriction
            non_skippable_in_stream_restrictions: (
                Campaign.VideoCampaignSettings.NonSkippableInStreamRestrictions
            )
            def __init__(
                self: _M,
                mapping: _M | Mapping | google.protobuf.message.Message | None = None,
                *,
                ignore_unknown_fields: bool = False,
                format_restriction: VideoAdFormatRestrictionEnum.VideoAdFormatRestriction = ...,
                non_skippable_in_stream_restrictions: Campaign.VideoCampaignSettings.NonSkippableInStreamRestrictions = ...,
            ) -> None: ...
            def __contains__(  # type: ignore[override]
                self,
                key: Literal[
                    "format_restriction", "non_skippable_in_stream_restrictions"
                ],
            ) -> bool: ...

        class VideoAdInventoryControl(proto.Message):
            allow_in_stream: bool
            allow_in_feed: bool
            allow_shorts: bool
            allow_non_skippable_in_stream: bool
            def __init__(
                self: _M,
                mapping: _M | Mapping | google.protobuf.message.Message | None = None,
                *,
                ignore_unknown_fields: bool = False,
                allow_in_stream: bool = ...,
                allow_in_feed: bool = ...,
                allow_shorts: bool = ...,
                allow_non_skippable_in_stream: bool = ...,
            ) -> None: ...
            def __contains__(  # type: ignore[override]
                self,
                key: Literal[
                    "allow_in_stream",
                    "allow_in_feed",
                    "allow_shorts",
                    "allow_non_skippable_in_stream",
                ],
            ) -> bool: ...

        class VideoAdSequence(proto.Message):
            steps: MutableSequence[Campaign.VideoCampaignSettings.VideoAdSequenceStep]
            minimum_duration: (
                VideoAdSequenceMinimumDurationEnum.VideoAdSequenceMinimumDuration
            )
            def __init__(
                self: _M,
                mapping: _M | Mapping | google.protobuf.message.Message | None = None,
                *,
                ignore_unknown_fields: bool = False,
                steps: MutableSequence[
                    Campaign.VideoCampaignSettings.VideoAdSequenceStep
                ] = ...,
                minimum_duration: VideoAdSequenceMinimumDurationEnum.VideoAdSequenceMinimumDuration = ...,
            ) -> None: ...
            def __contains__(  # type: ignore[override]
                self, key: Literal["steps", "minimum_duration"]
            ) -> bool: ...

        class VideoAdSequenceStep(proto.Message):
            video_ad_sequence_step_id: int
            asset_id: int
            ad_group_type: AdGroupTypeEnum.AdGroupType
            previous_step_id: int
            previous_step_interaction_type: (
                VideoAdSequenceInteractionTypeEnum.VideoAdSequenceInteractionType
            )
            def __init__(
                self: _M,
                mapping: _M | Mapping | google.protobuf.message.Message | None = None,
                *,
                ignore_unknown_fields: bool = False,
                video_ad_sequence_step_id: int = ...,
                asset_id: int = ...,
                ad_group_type: AdGroupTypeEnum.AdGroupType = ...,
                previous_step_id: int = ...,
                previous_step_interaction_type: VideoAdSequenceInteractionTypeEnum.VideoAdSequenceInteractionType = ...,
            ) -> None: ...
            def __contains__(  # type: ignore[override]
                self,
                key: Literal[
                    "video_ad_sequence_step_id",
                    "asset_id",
                    "ad_group_type",
                    "previous_step_id",
                    "previous_step_interaction_type",
                ],
            ) -> bool: ...

        video_ad_sequence: Campaign.VideoCampaignSettings.VideoAdSequence
        video_ad_inventory_control: (
            Campaign.VideoCampaignSettings.VideoAdInventoryControl
        )
        video_ad_format_control: Campaign.VideoCampaignSettings.VideoAdFormatControl
        def __init__(
            self: _M,
            mapping: _M | Mapping | google.protobuf.message.Message | None = None,
            *,
            ignore_unknown_fields: bool = False,
            video_ad_sequence: Campaign.VideoCampaignSettings.VideoAdSequence = ...,
            video_ad_inventory_control: Campaign.VideoCampaignSettings.VideoAdInventoryControl = ...,
            video_ad_format_control: Campaign.VideoCampaignSettings.VideoAdFormatControl = ...,
        ) -> None: ...
        def __contains__(  # type: ignore[override]
            self,
            key: Literal[
                "video_ad_sequence",
                "video_ad_inventory_control",
                "video_ad_format_control",
            ],
        ) -> bool: ...

    resource_name: str
    id: int
    name: str
    primary_status: CampaignPrimaryStatusEnum.CampaignPrimaryStatus
    primary_status_reasons: MutableSequence[
        CampaignPrimaryStatusReasonEnum.CampaignPrimaryStatusReason
    ]
    status: CampaignStatusEnum.CampaignStatus
    serving_status: CampaignServingStatusEnum.CampaignServingStatus
    bidding_strategy_system_status: (
        BiddingStrategySystemStatusEnum.BiddingStrategySystemStatus
    )
    ad_serving_optimization_status: (
        AdServingOptimizationStatusEnum.AdServingOptimizationStatus
    )
    advertising_channel_type: AdvertisingChannelTypeEnum.AdvertisingChannelType
    advertising_channel_sub_type: (
        AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType
    )
    tracking_url_template: str
    url_custom_parameters: MutableSequence[CustomParameter]
    local_services_campaign_settings: Campaign.LocalServicesCampaignSettings
    travel_campaign_settings: Campaign.TravelCampaignSettings
    demand_gen_campaign_settings: Campaign.DemandGenCampaignSettings
    video_campaign_settings: Campaign.VideoCampaignSettings
    pmax_campaign_settings: Campaign.PmaxCampaignSettings
    real_time_bidding_setting: RealTimeBiddingSetting
    network_settings: Campaign.NetworkSettings
    hotel_setting: Campaign.HotelSettingInfo
    dynamic_search_ads_setting: Campaign.DynamicSearchAdsSetting
    shopping_setting: Campaign.ShoppingSetting
    targeting_setting: TargetingSetting
    audience_setting: Campaign.AudienceSetting
    geo_target_type_setting: Campaign.GeoTargetTypeSetting
    local_campaign_setting: Campaign.LocalCampaignSetting
    app_campaign_setting: Campaign.AppCampaignSetting
    labels: MutableSequence[str]
    experiment_type: CampaignExperimentTypeEnum.CampaignExperimentType
    base_campaign: str
    campaign_budget: str
    bidding_strategy_type: BiddingStrategyTypeEnum.BiddingStrategyType
    accessible_bidding_strategy: str
    campaign_group: str
    start_date_time: str
    end_date_time: str
    final_url_suffix: str
    frequency_caps: MutableSequence[FrequencyCapEntry]
    video_brand_safety_suitability: BrandSafetySuitabilityEnum.BrandSafetySuitability
    vanity_pharma: Campaign.VanityPharma
    selective_optimization: Campaign.SelectiveOptimization
    optimization_goal_setting: Campaign.OptimizationGoalSetting
    tracking_setting: Campaign.TrackingSetting
    payment_mode: PaymentModeEnum.PaymentMode
    optimization_score: float
    excluded_parent_asset_field_types: MutableSequence[
        AssetFieldTypeEnum.AssetFieldType
    ]
    excluded_parent_asset_set_types: MutableSequence[AssetSetTypeEnum.AssetSetType]
    performance_max_upgrade: Campaign.PerformanceMaxUpgrade
    hotel_property_asset_set: str
    listing_type: ListingTypeEnum.ListingType
    asset_automation_settings: MutableSequence[Campaign.AssetAutomationSetting]
    keyword_match_type: CampaignKeywordMatchTypeEnum.CampaignKeywordMatchType
    brand_guidelines_enabled: bool
    brand_guidelines: Campaign.BrandGuidelines
    third_party_integration_partners: CampaignThirdPartyIntegrationPartners
    ai_max_setting: Campaign.AiMaxSetting
    contains_eu_political_advertising: (
        EuPoliticalAdvertisingStatusEnum.EuPoliticalAdvertisingStatus
    )
    feed_types: MutableSequence[AssetSetTypeEnum.AssetSetType]
    bidding_strategy: str
    commission: Commission
    manual_cpa: ManualCpa
    manual_cpc: ManualCpc
    manual_cpm: ManualCpm
    manual_cpv: ManualCpv
    maximize_conversions: MaximizeConversions
    maximize_conversion_value: MaximizeConversionValue
    target_cpa: TargetCpa
    target_impression_share: TargetImpressionShare
    target_roas: TargetRoas
    target_spend: TargetSpend
    percent_cpc: PercentCpc
    target_cpm: TargetCpm
    fixed_cpm: FixedCpm
    target_cpv: TargetCpv
    target_cpc: TargetCpc
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        resource_name: str = ...,
        id: int = ...,
        name: str = ...,
        primary_status: CampaignPrimaryStatusEnum.CampaignPrimaryStatus = ...,
        primary_status_reasons: MutableSequence[
            CampaignPrimaryStatusReasonEnum.CampaignPrimaryStatusReason
        ] = ...,
        status: CampaignStatusEnum.CampaignStatus = ...,
        serving_status: CampaignServingStatusEnum.CampaignServingStatus = ...,
        bidding_strategy_system_status: BiddingStrategySystemStatusEnum.BiddingStrategySystemStatus = ...,
        ad_serving_optimization_status: AdServingOptimizationStatusEnum.AdServingOptimizationStatus = ...,
        advertising_channel_type: AdvertisingChannelTypeEnum.AdvertisingChannelType = ...,
        advertising_channel_sub_type: AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType = ...,
        tracking_url_template: str = ...,
        url_custom_parameters: MutableSequence[CustomParameter] = ...,
        local_services_campaign_settings: Campaign.LocalServicesCampaignSettings = ...,
        travel_campaign_settings: Campaign.TravelCampaignSettings = ...,
        demand_gen_campaign_settings: Campaign.DemandGenCampaignSettings = ...,
        video_campaign_settings: Campaign.VideoCampaignSettings = ...,
        pmax_campaign_settings: Campaign.PmaxCampaignSettings = ...,
        real_time_bidding_setting: RealTimeBiddingSetting = ...,
        network_settings: Campaign.NetworkSettings = ...,
        hotel_setting: Campaign.HotelSettingInfo = ...,
        dynamic_search_ads_setting: Campaign.DynamicSearchAdsSetting = ...,
        shopping_setting: Campaign.ShoppingSetting = ...,
        targeting_setting: TargetingSetting = ...,
        audience_setting: Campaign.AudienceSetting = ...,
        geo_target_type_setting: Campaign.GeoTargetTypeSetting = ...,
        local_campaign_setting: Campaign.LocalCampaignSetting = ...,
        app_campaign_setting: Campaign.AppCampaignSetting = ...,
        labels: MutableSequence[str] = ...,
        experiment_type: CampaignExperimentTypeEnum.CampaignExperimentType = ...,
        base_campaign: str = ...,
        campaign_budget: str = ...,
        bidding_strategy_type: BiddingStrategyTypeEnum.BiddingStrategyType = ...,
        accessible_bidding_strategy: str = ...,
        campaign_group: str = ...,
        start_date_time: str = ...,
        end_date_time: str = ...,
        final_url_suffix: str = ...,
        frequency_caps: MutableSequence[FrequencyCapEntry] = ...,
        video_brand_safety_suitability: BrandSafetySuitabilityEnum.BrandSafetySuitability = ...,
        vanity_pharma: Campaign.VanityPharma = ...,
        selective_optimization: Campaign.SelectiveOptimization = ...,
        optimization_goal_setting: Campaign.OptimizationGoalSetting = ...,
        tracking_setting: Campaign.TrackingSetting = ...,
        payment_mode: PaymentModeEnum.PaymentMode = ...,
        optimization_score: float = ...,
        excluded_parent_asset_field_types: MutableSequence[
            AssetFieldTypeEnum.AssetFieldType
        ] = ...,
        excluded_parent_asset_set_types: MutableSequence[
            AssetSetTypeEnum.AssetSetType
        ] = ...,
        performance_max_upgrade: Campaign.PerformanceMaxUpgrade = ...,
        hotel_property_asset_set: str = ...,
        listing_type: ListingTypeEnum.ListingType = ...,
        asset_automation_settings: MutableSequence[
            Campaign.AssetAutomationSetting
        ] = ...,
        keyword_match_type: CampaignKeywordMatchTypeEnum.CampaignKeywordMatchType = ...,
        brand_guidelines_enabled: bool = ...,
        brand_guidelines: Campaign.BrandGuidelines = ...,
        third_party_integration_partners: CampaignThirdPartyIntegrationPartners = ...,
        ai_max_setting: Campaign.AiMaxSetting = ...,
        contains_eu_political_advertising: EuPoliticalAdvertisingStatusEnum.EuPoliticalAdvertisingStatus = ...,
        feed_types: MutableSequence[AssetSetTypeEnum.AssetSetType] = ...,
        bidding_strategy: str = ...,
        commission: Commission = ...,
        manual_cpa: ManualCpa = ...,
        manual_cpc: ManualCpc = ...,
        manual_cpm: ManualCpm = ...,
        manual_cpv: ManualCpv = ...,
        maximize_conversions: MaximizeConversions = ...,
        maximize_conversion_value: MaximizeConversionValue = ...,
        target_cpa: TargetCpa = ...,
        target_impression_share: TargetImpressionShare = ...,
        target_roas: TargetRoas = ...,
        target_spend: TargetSpend = ...,
        percent_cpc: PercentCpc = ...,
        target_cpm: TargetCpm = ...,
        fixed_cpm: FixedCpm = ...,
        target_cpv: TargetCpv = ...,
        target_cpc: TargetCpc = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "resource_name",
            "id",
            "name",
            "primary_status",
            "primary_status_reasons",
            "status",
            "serving_status",
            "bidding_strategy_system_status",
            "ad_serving_optimization_status",
            "advertising_channel_type",
            "advertising_channel_sub_type",
            "tracking_url_template",
            "url_custom_parameters",
            "local_services_campaign_settings",
            "travel_campaign_settings",
            "demand_gen_campaign_settings",
            "video_campaign_settings",
            "pmax_campaign_settings",
            "real_time_bidding_setting",
            "network_settings",
            "hotel_setting",
            "dynamic_search_ads_setting",
            "shopping_setting",
            "targeting_setting",
            "audience_setting",
            "geo_target_type_setting",
            "local_campaign_setting",
            "app_campaign_setting",
            "labels",
            "experiment_type",
            "base_campaign",
            "campaign_budget",
            "bidding_strategy_type",
            "accessible_bidding_strategy",
            "campaign_group",
            "start_date_time",
            "end_date_time",
            "final_url_suffix",
            "frequency_caps",
            "video_brand_safety_suitability",
            "vanity_pharma",
            "selective_optimization",
            "optimization_goal_setting",
            "tracking_setting",
            "payment_mode",
            "optimization_score",
            "excluded_parent_asset_field_types",
            "excluded_parent_asset_set_types",
            "performance_max_upgrade",
            "hotel_property_asset_set",
            "listing_type",
            "asset_automation_settings",
            "keyword_match_type",
            "brand_guidelines_enabled",
            "brand_guidelines",
            "third_party_integration_partners",
            "ai_max_setting",
            "contains_eu_political_advertising",
            "feed_types",
            "bidding_strategy",
            "commission",
            "manual_cpa",
            "manual_cpc",
            "manual_cpm",
            "manual_cpv",
            "maximize_conversions",
            "maximize_conversion_value",
            "target_cpa",
            "target_impression_share",
            "target_roas",
            "target_spend",
            "percent_cpc",
            "target_cpm",
            "fixed_cpm",
            "target_cpv",
            "target_cpc",
        ],
    ) -> bool: ...



from .async_client import (
    RemarketingActionServiceAsyncClient as RemarketingActionServiceAsyncClient,
)
from .client import RemarketingActionServiceClient as RemarketingActionServiceClient

__all__ = ["RemarketingActionServiceClient", "RemarketingActionServiceAsyncClient"]



from .async_client import (
    ConversionCustomVariableServiceAsyncClient as ConversionCustomVariableServiceAsyncClient,
)
from .client import (
    ConversionCustomVariableServiceClient as ConversionCustomVariableServiceClient,
)

__all__ = [
    "ConversionCustomVariableServiceClient",
    "ConversionCustomVariableServiceAsyncClient",
]



from .async_client import (
    CustomerManagerLinkServiceAsyncClient as CustomerManagerLinkServiceAsyncClient,
)
from .client import CustomerManagerLinkServiceClient as CustomerManagerLinkServiceClient

__all__ = ["CustomerManagerLinkServiceClient", "CustomerManagerLinkServiceAsyncClient"]



from .async_client import (
    ContentCreatorInsightsServiceAsyncClient as ContentCreatorInsightsServiceAsyncClient,
)
from .client import (
    ContentCreatorInsightsServiceClient as ContentCreatorInsightsServiceClient,
)

__all__ = [
    "ContentCreatorInsightsServiceClient",
    "ContentCreatorInsightsServiceAsyncClient",
]



from .base import CampaignGroupServiceTransport as CampaignGroupServiceTransport
from .grpc import CampaignGroupServiceGrpcTransport as CampaignGroupServiceGrpcTransport
from .grpc_asyncio import (
    CampaignGroupServiceGrpcAsyncIOTransport as CampaignGroupServiceGrpcAsyncIOTransport,
)

__all__ = [
    "CampaignGroupServiceTransport",
    "CampaignGroupServiceGrpcTransport",
    "CampaignGroupServiceGrpcAsyncIOTransport",
]



from collections.abc import Mapping
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

from google.ads.googleads.v23.common.types.campaign_goal_settings import (
    CampaignGoalSettings,
)
from google.ads.googleads.v23.enums.types.goal_type import GoalTypeEnum

_M = TypeVar("_M")

class CampaignGoalConfig(proto.Message):
    resource_name: str
    campaign: str
    goal: str
    goal_type: GoalTypeEnum.GoalType
    campaign_retention_settings: CampaignGoalSettings.CampaignRetentionGoalSettings
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        resource_name: str = ...,
        campaign: str = ...,
        goal: str = ...,
        goal_type: GoalTypeEnum.GoalType = ...,
        campaign_retention_settings: CampaignGoalSettings.CampaignRetentionGoalSettings = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "resource_name",
            "campaign",
            "goal",
            "goal_type",
            "campaign_retention_settings",
        ],
    ) -> bool: ...



from .base import ReachPlanServiceTransport as ReachPlanServiceTransport
from .grpc import ReachPlanServiceGrpcTransport as ReachPlanServiceGrpcTransport
from .grpc_asyncio import (
    ReachPlanServiceGrpcAsyncIOTransport as ReachPlanServiceGrpcAsyncIOTransport,
)

__all__ = [
    "ReachPlanServiceTransport",
    "ReachPlanServiceGrpcTransport",
    "ReachPlanServiceGrpcAsyncIOTransport",
]



from collections.abc import Mapping
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

_M = TypeVar("_M")

class PerStoreView(proto.Message):
    resource_name: str
    place_id: str
    address1: str
    address2: str
    business_name: str
    city: str
    country_code: str
    phone_number: str
    postal_code: str
    province: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        resource_name: str = ...,
        place_id: str = ...,
        address1: str = ...,
        address2: str = ...,
        business_name: str = ...,
        city: str = ...,
        country_code: str = ...,
        phone_number: str = ...,
        postal_code: str = ...,
        province: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "resource_name",
            "place_id",
            "address1",
            "address2",
            "business_name",
            "city",
            "country_code",
            "phone_number",
            "postal_code",
            "province",
        ],
    ) -> bool: ...



from collections.abc import Mapping, MutableSequence
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

_M = TypeVar("_M")

class ExperimentArm(proto.Message):
    resource_name: str
    experiment: str
    name: str
    control: bool
    traffic_split: int
    campaigns: MutableSequence[str]
    in_design_campaigns: MutableSequence[str]
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        resource_name: str = ...,
        experiment: str = ...,
        name: str = ...,
        control: bool = ...,
        traffic_split: int = ...,
        campaigns: MutableSequence[str] = ...,
        in_design_campaigns: MutableSequence[str] = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "resource_name",
            "experiment",
            "name",
            "control",
            "traffic_split",
            "campaigns",
            "in_design_campaigns",
        ],
    ) -> bool: ...



from collections.abc import Mapping
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

from google.ads.googleads.v22.enums.types.asset_field_type import AssetFieldTypeEnum
from google.ads.googleads.v22.enums.types.asset_link_status import AssetLinkStatusEnum

_M = TypeVar("_M")

class FinalUrlExpansionAssetView(proto.Message):
    resource_name: str
    campaign: str
    asset: str
    field_type: AssetFieldTypeEnum.AssetFieldType
    status: AssetLinkStatusEnum.AssetLinkStatus
    final_url: str
    ad_group: str
    asset_group: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        resource_name: str = ...,
        campaign: str = ...,
        asset: str = ...,
        field_type: AssetFieldTypeEnum.AssetFieldType = ...,
        status: AssetLinkStatusEnum.AssetLinkStatus = ...,
        final_url: str = ...,
        ad_group: str = ...,
        asset_group: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "resource_name",
            "campaign",
            "asset",
            "field_type",
            "status",
            "final_url",
            "ad_group",
            "asset_group",
        ],
    ) -> bool: ...



from collections.abc import Mapping, MutableSequence
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

from google.ads.googleads.v23.enums.types.advertising_channel_type import (
    AdvertisingChannelTypeEnum,
)
from google.ads.googleads.v23.enums.types.asset_field_type import AssetFieldTypeEnum

_M = TypeVar("_M")

class AssetGenerationExistingContext(proto.Message):
    existing_asset_group: str
    existing_ad_group_ad: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        existing_asset_group: str = ...,
        existing_ad_group_ad: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["existing_asset_group", "existing_ad_group_ad"]
    ) -> bool: ...

class FinalUrlImageGenerationInput(proto.Message):
    final_url: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        final_url: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["final_url"]
    ) -> bool: ...

class FreeformImageGenerationInput(proto.Message):
    freeform_prompt: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        freeform_prompt: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["freeform_prompt"]
    ) -> bool: ...

class GenerateImagesRequest(proto.Message):
    customer_id: str
    asset_field_types: MutableSequence[AssetFieldTypeEnum.AssetFieldType]
    advertising_channel_type: AdvertisingChannelTypeEnum.AdvertisingChannelType
    final_url_generation: FinalUrlImageGenerationInput
    freeform_generation: FreeformImageGenerationInput
    product_recontext_generation: ProductRecontextGenerationImageInput
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        customer_id: str = ...,
        asset_field_types: MutableSequence[AssetFieldTypeEnum.AssetFieldType] = ...,
        advertising_channel_type: AdvertisingChannelTypeEnum.AdvertisingChannelType = ...,
        final_url_generation: FinalUrlImageGenerationInput = ...,
        freeform_generation: FreeformImageGenerationInput = ...,
        product_recontext_generation: ProductRecontextGenerationImageInput = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "customer_id",
            "asset_field_types",
            "advertising_channel_type",
            "final_url_generation",
            "freeform_generation",
            "product_recontext_generation",
        ],
    ) -> bool: ...

class GenerateImagesResponse(proto.Message):
    generated_images: MutableSequence[GeneratedImage]
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        generated_images: MutableSequence[GeneratedImage] = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["generated_images"]
    ) -> bool: ...

class GenerateTextRequest(proto.Message):
    customer_id: str
    asset_field_types: MutableSequence[AssetFieldTypeEnum.AssetFieldType]
    final_url: str
    freeform_prompt: str
    keywords: MutableSequence[str]
    existing_generation_context: AssetGenerationExistingContext
    advertising_channel_type: AdvertisingChannelTypeEnum.AdvertisingChannelType
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        customer_id: str = ...,
        asset_field_types: MutableSequence[AssetFieldTypeEnum.AssetFieldType] = ...,
        final_url: str = ...,
        freeform_prompt: str = ...,
        keywords: MutableSequence[str] = ...,
        existing_generation_context: AssetGenerationExistingContext = ...,
        advertising_channel_type: AdvertisingChannelTypeEnum.AdvertisingChannelType = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "customer_id",
            "asset_field_types",
            "final_url",
            "freeform_prompt",
            "keywords",
            "existing_generation_context",
            "advertising_channel_type",
        ],
    ) -> bool: ...

class GenerateTextResponse(proto.Message):
    generated_text: MutableSequence[GeneratedText]
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        generated_text: MutableSequence[GeneratedText] = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["generated_text"]
    ) -> bool: ...

class GeneratedImage(proto.Message):
    image_temporary_url: str
    asset_field_type: AssetFieldTypeEnum.AssetFieldType
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        image_temporary_url: str = ...,
        asset_field_type: AssetFieldTypeEnum.AssetFieldType = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["image_temporary_url", "asset_field_type"]
    ) -> bool: ...

class GeneratedText(proto.Message):
    text: str
    asset_field_type: AssetFieldTypeEnum.AssetFieldType
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        text: str = ...,
        asset_field_type: AssetFieldTypeEnum.AssetFieldType = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["text", "asset_field_type"]
    ) -> bool: ...

class ProductRecontextGenerationImageInput(proto.Message):
    prompt: str
    source_images: MutableSequence[SourceImage]
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        prompt: str = ...,
        source_images: MutableSequence[SourceImage] = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["prompt", "source_images"]
    ) -> bool: ...

class SourceImage(proto.Message):
    image_data: bytes
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        image_data: bytes = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["image_data"]
    ) -> bool: ...



from .base import UserListServiceTransport as UserListServiceTransport
from .grpc import UserListServiceGrpcTransport as UserListServiceGrpcTransport
from .grpc_asyncio import (
    UserListServiceGrpcAsyncIOTransport as UserListServiceGrpcAsyncIOTransport,
)

__all__ = [
    "UserListServiceTransport",
    "UserListServiceGrpcTransport",
    "UserListServiceGrpcAsyncIOTransport",
]



from collections.abc import Mapping
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

from google.ads.googleads.v21.enums.types.fixed_cpm_goal import FixedCpmGoalEnum
from google.ads.googleads.v21.enums.types.fixed_cpm_target_frequency_time_unit import (
    FixedCpmTargetFrequencyTimeUnitEnum,
)
from google.ads.googleads.v21.enums.types.target_frequency_time_unit import (
    TargetFrequencyTimeUnitEnum,
)
from google.ads.googleads.v21.enums.types.target_impression_share_location import (
    TargetImpressionShareLocationEnum,
)

_M = TypeVar("_M")

class Commission(proto.Message):
    commission_rate_micros: int
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        commission_rate_micros: int = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["commission_rate_micros"]
    ) -> bool: ...

class EnhancedCpc(proto.Message):
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: NoReturn
    ) -> bool: ...

class FixedCpm(proto.Message):
    goal: FixedCpmGoalEnum.FixedCpmGoal
    target_frequency_info: FixedCpmTargetFrequencyGoalInfo
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        goal: FixedCpmGoalEnum.FixedCpmGoal = ...,
        target_frequency_info: FixedCpmTargetFrequencyGoalInfo = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["goal", "target_frequency_info"]
    ) -> bool: ...

class FixedCpmTargetFrequencyGoalInfo(proto.Message):
    target_count: int
    time_unit: FixedCpmTargetFrequencyTimeUnitEnum.FixedCpmTargetFrequencyTimeUnit
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        target_count: int = ...,
        time_unit: FixedCpmTargetFrequencyTimeUnitEnum.FixedCpmTargetFrequencyTimeUnit = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["target_count", "time_unit"]
    ) -> bool: ...

class ManualCpa(proto.Message):
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: NoReturn
    ) -> bool: ...

class ManualCpc(proto.Message):
    enhanced_cpc_enabled: bool
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        enhanced_cpc_enabled: bool = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["enhanced_cpc_enabled"]
    ) -> bool: ...

class ManualCpm(proto.Message):
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: NoReturn
    ) -> bool: ...

class ManualCpv(proto.Message):
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: NoReturn
    ) -> bool: ...

class MaximizeConversionValue(proto.Message):
    target_roas: float
    cpc_bid_ceiling_micros: int
    cpc_bid_floor_micros: int
    target_roas_tolerance_percent_millis: int
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        target_roas: float = ...,
        cpc_bid_ceiling_micros: int = ...,
        cpc_bid_floor_micros: int = ...,
        target_roas_tolerance_percent_millis: int = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "target_roas",
            "cpc_bid_ceiling_micros",
            "cpc_bid_floor_micros",
            "target_roas_tolerance_percent_millis",
        ],
    ) -> bool: ...

class MaximizeConversions(proto.Message):
    cpc_bid_ceiling_micros: int
    cpc_bid_floor_micros: int
    target_cpa_micros: int
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        cpc_bid_ceiling_micros: int = ...,
        cpc_bid_floor_micros: int = ...,
        target_cpa_micros: int = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "cpc_bid_ceiling_micros", "cpc_bid_floor_micros", "target_cpa_micros"
        ],
    ) -> bool: ...

class PercentCpc(proto.Message):
    cpc_bid_ceiling_micros: int
    enhanced_cpc_enabled: bool
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        cpc_bid_ceiling_micros: int = ...,
        enhanced_cpc_enabled: bool = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["cpc_bid_ceiling_micros", "enhanced_cpc_enabled"]
    ) -> bool: ...

class TargetCpa(proto.Message):
    target_cpa_micros: int
    cpc_bid_ceiling_micros: int
    cpc_bid_floor_micros: int
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        target_cpa_micros: int = ...,
        cpc_bid_ceiling_micros: int = ...,
        cpc_bid_floor_micros: int = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "target_cpa_micros", "cpc_bid_ceiling_micros", "cpc_bid_floor_micros"
        ],
    ) -> bool: ...

class TargetCpm(proto.Message):
    target_frequency_goal: TargetCpmTargetFrequencyGoal
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        target_frequency_goal: TargetCpmTargetFrequencyGoal = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["target_frequency_goal"]
    ) -> bool: ...

class TargetCpmTargetFrequencyGoal(proto.Message):
    target_count: int
    time_unit: TargetFrequencyTimeUnitEnum.TargetFrequencyTimeUnit
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        target_count: int = ...,
        time_unit: TargetFrequencyTimeUnitEnum.TargetFrequencyTimeUnit = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["target_count", "time_unit"]
    ) -> bool: ...

class TargetCpv(proto.Message):
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: NoReturn
    ) -> bool: ...

class TargetImpressionShare(proto.Message):
    location: TargetImpressionShareLocationEnum.TargetImpressionShareLocation
    location_fraction_micros: int
    cpc_bid_ceiling_micros: int
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        location: TargetImpressionShareLocationEnum.TargetImpressionShareLocation = ...,
        location_fraction_micros: int = ...,
        cpc_bid_ceiling_micros: int = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal["location", "location_fraction_micros", "cpc_bid_ceiling_micros"],
    ) -> bool: ...

class TargetRoas(proto.Message):
    target_roas: float
    cpc_bid_ceiling_micros: int
    cpc_bid_floor_micros: int
    target_roas_tolerance_percent_millis: int
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        target_roas: float = ...,
        cpc_bid_ceiling_micros: int = ...,
        cpc_bid_floor_micros: int = ...,
        target_roas_tolerance_percent_millis: int = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "target_roas",
            "cpc_bid_ceiling_micros",
            "cpc_bid_floor_micros",
            "target_roas_tolerance_percent_millis",
        ],
    ) -> bool: ...

class TargetSpend(proto.Message):
    target_spend_micros: int
    cpc_bid_ceiling_micros: int
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        target_spend_micros: int = ...,
        cpc_bid_ceiling_micros: int = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["target_spend_micros", "cpc_bid_ceiling_micros"]
    ) -> bool: ...



from .async_client import BenchmarksServiceAsyncClient as BenchmarksServiceAsyncClient
from .client import BenchmarksServiceClient as BenchmarksServiceClient

__all__ = ["BenchmarksServiceClient", "BenchmarksServiceAsyncClient"]



from .async_client import (
    AdGroupAssetServiceAsyncClient as AdGroupAssetServiceAsyncClient,
)
from .client import AdGroupAssetServiceClient as AdGroupAssetServiceClient

__all__ = ["AdGroupAssetServiceClient", "AdGroupAssetServiceAsyncClient"]



from .async_client import (
    GeoTargetConstantServiceAsyncClient as GeoTargetConstantServiceAsyncClient,
)
from .client import GeoTargetConstantServiceClient as GeoTargetConstantServiceClient

__all__ = ["GeoTargetConstantServiceClient", "GeoTargetConstantServiceAsyncClient"]



import abc
from typing import Awaitable, Callable, Sequence

from _typeshed import Incomplete
from google.api_core import gapic_v1
from google.auth import credentials as ga_credentials

from google.ads.googleads.v21.services.types import google_ads_service

__all__ = ["GoogleAdsServiceTransport"]

class GoogleAdsServiceTransport(abc.ABC):
    AUTH_SCOPES: Incomplete
    DEFAULT_HOST: str
    def __init__(
        self,
        *,
        host: str = "googleads.googleapis.com",
        credentials: ga_credentials.Credentials | None = None,
        credentials_file: str | None = None,
        scopes: Sequence[str] | None = None,
        quota_project_id: str | None = None,
        client_info: gapic_v1.client_info.ClientInfo = ...,
        always_use_jwt_access: bool | None = False,
        api_audience: str | None = None,
        **kwargs,
    ) -> None: ...
    @property
    def host(self): ...
    def close(self) -> None: ...
    @property
    def search(
        self,
    ) -> Callable[
        [google_ads_service.SearchGoogleAdsRequest],
        google_ads_service.SearchGoogleAdsResponse
        | Awaitable[google_ads_service.SearchGoogleAdsResponse],
    ]: ...
    @property
    def search_stream(
        self,
    ) -> Callable[
        [google_ads_service.SearchGoogleAdsStreamRequest],
        google_ads_service.SearchGoogleAdsStreamResponse
        | Awaitable[google_ads_service.SearchGoogleAdsStreamResponse],
    ]: ...
    @property
    def mutate(
        self,
    ) -> Callable[
        [google_ads_service.MutateGoogleAdsRequest],
        google_ads_service.MutateGoogleAdsResponse
        | Awaitable[google_ads_service.MutateGoogleAdsResponse],
    ]: ...
    @property
    def kind(self) -> str: ...



from .async_client import (
    ConversionValueRuleServiceAsyncClient as ConversionValueRuleServiceAsyncClient,
)
from .client import ConversionValueRuleServiceClient as ConversionValueRuleServiceClient

__all__ = ["ConversionValueRuleServiceClient", "ConversionValueRuleServiceAsyncClient"]



from .base import BrandSuggestionServiceTransport as BrandSuggestionServiceTransport
from .grpc import (
    BrandSuggestionServiceGrpcTransport as BrandSuggestionServiceGrpcTransport,
)
from .grpc_asyncio import (
    BrandSuggestionServiceGrpcAsyncIOTransport as BrandSuggestionServiceGrpcAsyncIOTransport,
)

__all__ = [
    "BrandSuggestionServiceTransport",
    "BrandSuggestionServiceGrpcTransport",
    "BrandSuggestionServiceGrpcAsyncIOTransport",
]



from collections.abc import Mapping, MutableSequence
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from google.protobuf.field_mask_pb2 import FieldMask
from google.rpc.status_pb2 import Status
from typing_extensions import Literal

from google.ads.googleads.v21.enums.types.response_content_type import (
    ResponseContentTypeEnum,
)
from google.ads.googleads.v21.enums.types.smart_campaign_not_eligible_reason import (
    SmartCampaignNotEligibleReasonEnum,
)
from google.ads.googleads.v21.enums.types.smart_campaign_status import (
    SmartCampaignStatusEnum,
)
from google.ads.googleads.v21.resources.types.smart_campaign_setting import (
    SmartCampaignSetting,
)

_M = TypeVar("_M")

class GetSmartCampaignStatusRequest(proto.Message):
    resource_name: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        resource_name: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["resource_name"]
    ) -> bool: ...

class GetSmartCampaignStatusResponse(proto.Message):
    smart_campaign_status: SmartCampaignStatusEnum.SmartCampaignStatus
    not_eligible_details: SmartCampaignNotEligibleDetails
    eligible_details: SmartCampaignEligibleDetails
    paused_details: SmartCampaignPausedDetails
    removed_details: SmartCampaignRemovedDetails
    ended_details: SmartCampaignEndedDetails
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        smart_campaign_status: SmartCampaignStatusEnum.SmartCampaignStatus = ...,
        not_eligible_details: SmartCampaignNotEligibleDetails = ...,
        eligible_details: SmartCampaignEligibleDetails = ...,
        paused_details: SmartCampaignPausedDetails = ...,
        removed_details: SmartCampaignRemovedDetails = ...,
        ended_details: SmartCampaignEndedDetails = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "smart_campaign_status",
            "not_eligible_details",
            "eligible_details",
            "paused_details",
            "removed_details",
            "ended_details",
        ],
    ) -> bool: ...

class MutateSmartCampaignSettingResult(proto.Message):
    resource_name: str
    smart_campaign_setting: SmartCampaignSetting
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        resource_name: str = ...,
        smart_campaign_setting: SmartCampaignSetting = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["resource_name", "smart_campaign_setting"]
    ) -> bool: ...

class MutateSmartCampaignSettingsRequest(proto.Message):
    customer_id: str
    operations: MutableSequence[SmartCampaignSettingOperation]
    partial_failure: bool
    validate_only: bool
    response_content_type: ResponseContentTypeEnum.ResponseContentType
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        customer_id: str = ...,
        operations: MutableSequence[SmartCampaignSettingOperation] = ...,
        partial_failure: bool = ...,
        validate_only: bool = ...,
        response_content_type: ResponseContentTypeEnum.ResponseContentType = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "customer_id",
            "operations",
            "partial_failure",
            "validate_only",
            "response_content_type",
        ],
    ) -> bool: ...

class MutateSmartCampaignSettingsResponse(proto.Message):
    partial_failure_error: Status
    results: MutableSequence[MutateSmartCampaignSettingResult]
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        partial_failure_error: Status = ...,
        results: MutableSequence[MutateSmartCampaignSettingResult] = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["partial_failure_error", "results"]
    ) -> bool: ...

class SmartCampaignEligibleDetails(proto.Message):
    last_impression_date_time: str
    end_date_time: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        last_impression_date_time: str = ...,
        end_date_time: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["last_impression_date_time", "end_date_time"]
    ) -> bool: ...

class SmartCampaignEndedDetails(proto.Message):
    end_date_time: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        end_date_time: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["end_date_time"]
    ) -> bool: ...

class SmartCampaignNotEligibleDetails(proto.Message):
    not_eligible_reason: (
        SmartCampaignNotEligibleReasonEnum.SmartCampaignNotEligibleReason
    )
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        not_eligible_reason: SmartCampaignNotEligibleReasonEnum.SmartCampaignNotEligibleReason = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["not_eligible_reason"]
    ) -> bool: ...

class SmartCampaignPausedDetails(proto.Message):
    paused_date_time: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        paused_date_time: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["paused_date_time"]
    ) -> bool: ...

class SmartCampaignRemovedDetails(proto.Message):
    removed_date_time: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        removed_date_time: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["removed_date_time"]
    ) -> bool: ...

class SmartCampaignSettingOperation(proto.Message):
    update: SmartCampaignSetting
    update_mask: FieldMask
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        update: SmartCampaignSetting = ...,
        update_mask: FieldMask = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["update", "update_mask"]
    ) -> bool: ...



from .async_client import (
    AdGroupBidModifierServiceAsyncClient as AdGroupBidModifierServiceAsyncClient,
)
from .client import AdGroupBidModifierServiceClient as AdGroupBidModifierServiceClient

__all__ = ["AdGroupBidModifierServiceClient", "AdGroupBidModifierServiceAsyncClient"]



from collections.abc import Mapping
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from google.protobuf.field_mask_pb2 import FieldMask
from typing_extensions import Literal

from google.ads.googleads.v22.resources.types.account_budget_proposal import (
    AccountBudgetProposal,
)

_M = TypeVar("_M")

class AccountBudgetProposalOperation(proto.Message):
    update_mask: FieldMask
    create: AccountBudgetProposal
    remove: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        update_mask: FieldMask = ...,
        create: AccountBudgetProposal = ...,
        remove: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["update_mask", "create", "remove"]
    ) -> bool: ...

class MutateAccountBudgetProposalRequest(proto.Message):
    customer_id: str
    operation: AccountBudgetProposalOperation
    validate_only: bool
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        customer_id: str = ...,
        operation: AccountBudgetProposalOperation = ...,
        validate_only: bool = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["customer_id", "operation", "validate_only"]
    ) -> bool: ...

class MutateAccountBudgetProposalResponse(proto.Message):
    result: MutateAccountBudgetProposalResult
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        result: MutateAccountBudgetProposalResult = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["result"]
    ) -> bool: ...

class MutateAccountBudgetProposalResult(proto.Message):
    resource_name: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        resource_name: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["resource_name"]
    ) -> bool: ...



from .async_client import (
    CustomerUserAccessServiceAsyncClient as CustomerUserAccessServiceAsyncClient,
)
from .client import CustomerUserAccessServiceClient as CustomerUserAccessServiceClient

__all__ = ["CustomerUserAccessServiceClient", "CustomerUserAccessServiceAsyncClient"]



from .async_client import (
    AdGroupAdLabelServiceAsyncClient as AdGroupAdLabelServiceAsyncClient,
)
from .client import AdGroupAdLabelServiceClient as AdGroupAdLabelServiceClient

__all__ = ["AdGroupAdLabelServiceClient", "AdGroupAdLabelServiceAsyncClient"]



from .base import CampaignSharedSetServiceTransport as CampaignSharedSetServiceTransport
from .grpc import (
    CampaignSharedSetServiceGrpcTransport as CampaignSharedSetServiceGrpcTransport,
)
from .grpc_asyncio import (
    CampaignSharedSetServiceGrpcAsyncIOTransport as CampaignSharedSetServiceGrpcAsyncIOTransport,
)

__all__ = [
    "CampaignSharedSetServiceTransport",
    "CampaignSharedSetServiceGrpcTransport",
    "CampaignSharedSetServiceGrpcAsyncIOTransport",
]



from collections.abc import Mapping
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

from google.ads.googleads.v23.enums.types.call_tracking_display_location import (
    CallTrackingDisplayLocationEnum,
)
from google.ads.googleads.v23.enums.types.call_type import CallTypeEnum
from google.ads.googleads.v23.enums.types.google_voice_call_status import (
    GoogleVoiceCallStatusEnum,
)

_M = TypeVar("_M")

class CallView(proto.Message):
    resource_name: str
    caller_country_code: str
    caller_area_code: str
    call_duration_seconds: int
    start_call_date_time: str
    end_call_date_time: str
    call_tracking_display_location: (
        CallTrackingDisplayLocationEnum.CallTrackingDisplayLocation
    )
    type_: CallTypeEnum.CallType
    call_status: GoogleVoiceCallStatusEnum.GoogleVoiceCallStatus
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        resource_name: str = ...,
        caller_country_code: str = ...,
        caller_area_code: str = ...,
        call_duration_seconds: int = ...,
        start_call_date_time: str = ...,
        end_call_date_time: str = ...,
        call_tracking_display_location: CallTrackingDisplayLocationEnum.CallTrackingDisplayLocation = ...,
        type_: CallTypeEnum.CallType = ...,
        call_status: GoogleVoiceCallStatusEnum.GoogleVoiceCallStatus = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "resource_name",
            "caller_country_code",
            "caller_area_code",
            "call_duration_seconds",
            "start_call_date_time",
            "end_call_date_time",
            "call_tracking_display_location",
            "type_",
            "call_status",
        ],
    ) -> bool: ...



from .async_client import DataLinkServiceAsyncClient as DataLinkServiceAsyncClient
from .client import DataLinkServiceClient as DataLinkServiceClient

__all__ = ["DataLinkServiceClient", "DataLinkServiceAsyncClient"]
